/***************************************************************************************************
*  Copyright (C) Yokogawa Electric Corporation 2003,2004  All Rights Reserved.                     *
*
*  $Workfile:   YEC_EJA0101PA.ddl  $
*    $Author:   ueno.madoka  $
*  $Revision:   1.8  $
*      $Date:   16 Jul 2007 14:38:20  $
*                                                                                                  *
****************************************************************************************************
*
*
*  PROJECT_NAME        EJA Profibus PA
*
*  FIRST_AUTHOR        Madoka Ueno
*
*  FILE_DESCRIPTION    EJA (Profibus PA) DD\[Xt@C
*
*  FUNCTIONAL_MODULE_DESCRIPTION  Device Descriprion
*
*  DICTIONARY          YEC_EJA0101PA.dct
*
*  EJA****PA.ddl
*   |  | | |___> PROFIBUS PA
*   |  | |_____> DD Revision(Hex)  normal:1`
*   |  |_______> Device Revision(Hex)
*   |__________> i
*
*    ̃t@C͈ȉSIEMENSWDDLt@Cɍ쐬Ă܂B 
*    SIPASTTP__02.ddl   (Revision:1.11 Date:   Mar 29 2000 14:33:10)
*    CN[ht@CA֘At@CȂǂ PA_Sensor_Press_Profile3.DevicesQƁB
*
*  RELATED_DOCUMENTS
*    Document No.        Name               Title
*---------------------------------------------------------------------------------------------------
*    STR-PBEJA-B007      M. Ueno            EJA PROFIBUS PA EDD Specification
*=================================================================================================*/

MANUFACTURER	55,
DEVICE_TYPE		0x070D,
DEVICE_REVISION 1,
DD_REVISION		1


/* Includes ------------------------------------------------------ */

#include "YEC_EJA0101PAmacro.inc"

#define EXTRA_ITEMS_VIEW_MENU_SPECIALIST		Menu_S_alarm, OnlineWindow_diagnosis
#define EXTRA_ITEMS_VIEW_MENU_MAINTENANCE		Menu_M_alarm, OnlineWindow_diagnosis

#define YT1_LABEL	[trans_pres_sensor_value_trend_label]
#define YT1_VALUE	trans1_sensor_value
#define	YT1_LRV		trans1_scale_in_lower_value
#define YT1_URV		trans1_scale_in_upper_value

#define YT2_LABEL	[trans1_primary_value_trend_label]
#define YT2_VALUE	trans1_primary_value
#define	YT2_LRV		trans1_scale_out_lower_value
#define YT2_URV		trans1_scale_out_upper_value

#define YT3_LABEL	[func1_eja_out_label]
#define YT3_VALUE	func1_AI_out_value 
#define	YT3_LRV		func1_AI_out_lower_range_value
#define YT3_URV		func1_AI_out_upper_range_value

#include "SI_YT.inc"
#include "SIPAST_Macros_300.inc"
#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"
#include "SI_ViewM.inc"
#include "SIPAST.inc"        /* PDM PA indet check */
#include "YEC_EJA0101PA.inc"



/*
*********************************************************************
    Unit relations 
*********************************************************************
*/
/* Physical Block */
/* no unit relations */

/* Transducer Block */
/* See SIPASTTP_300.inc (SV1U, SU) */

UNIT TB_SENSOR_PRIMARY_VALUE_UNIT
{
	trans1_primary_value_unit:
	
	trans1_primary_value,
	trans1_scale_out_lower_value,
	trans1_scale_out_upper_value,
	func1_AI_pv_upper_range_value,
	func1_AI_pv_lower_range_value,
	func1_AI_simulate_value
}

UNIT TB_STATIC_PRESSURE_VALUE_UNIT
{
	trans1_static_press_unit:
	
	trans1_static_press_value,
	func2_AI_pv_upper_range_value,
	func2_AI_pv_lower_range_value,
	func2_AI_simulate_value
}



/*
*********************************************************************
   Commands
*********************************************************************
*/

COMMAND read_phys_soft_desc
{
	BLOCK physical_block;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_soft_desc
		}
	}
}


COMMAND read_phys_set_address
{
	BLOCK physical_block;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			phys_set_address
		}
	}
}

COMMAND write_phys_set_address
{
	BLOCK physical_block;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			phys_set_address
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_static_press
{
	BLOCK transducer_block_1;
	INDEX 59;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_static_press_value,
			trans1_static_press_value_status_quality	<0xFC>,
			trans1_static_press_value_status_limit  	<0x03>
		}
	}
}


COMMAND read_trans1_static_press_unit
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_static_press_unit
		}
	}
}


COMMAND write_trans1_static_press_unit
{
	BLOCK transducer_block_1;
	INDEX 60;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_static_press_unit
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_serial_number
{
	BLOCK transducer_block_1;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_serial_number
		}
	}
}


COMMAND read_trans1_trim_pv_zero
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_trim_pv_zero
		}
	}
}


COMMAND write_trans1_trim_pv_zero
{
	BLOCK transducer_block_1;
	INDEX 62;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_trim_pv_zero
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_trim_mode
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_trim_mode
		}
	}
}


COMMAND write_trans1_trim_mode
{
	BLOCK transducer_block_1;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_trim_mode
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_ext_zero_enable
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_ext_zero_enable
		}
	}
}


COMMAND write_trans1_ext_zero_enable
{
	BLOCK transducer_block_1;
	INDEX 64;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_ext_zero_enable
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_display_mode
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_display_mode
		}
	}
}


COMMAND read_trans1_model
{
	BLOCK transducer_block_1;
	INDEX 65;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_model
		}
	}
}


COMMAND write_trans1_display_mode
{
	BLOCK transducer_block_1;
	INDEX 66;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_display_mode
		}
		REPLY
		{
		}
	}
}


COMMAND read_trans1_display_cycle
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_display_cycle
		}
	}
}


COMMAND write_trans1_display_cycle
{
	BLOCK transducer_block_1;
	INDEX 67;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_display_cycle
		}
		REPLY
		{
		}
	}
}



/*
*********************************************************************
    VALIABLE
*********************************************************************
*/

/* PB */
VARIABLE phys_soft_desc
{
	LABEL		[phys_soft_desc_label];
	HELP		[phys_soft_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{
		DEFAULT_VALUE "";
	}
	HANDLING	READ;
}

VARIABLE phys_set_address
{
	LABEL		[set_address];
	HELP		[set_address_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE 0;
	}
	HANDLING	READ & WRITE;
}

/* TB */
VARIABLE trans1_static_press_value
{
	LABEL		[trans1_static_press_value_label];
	HELP		[trans1_static_press_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
}

VARIABLE trans1_static_press_value_status_quality
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;/* DTM_MOD_000 */
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans1_static_press_value_status_limit			LIKE VARIABLE	trans1_static_press_value_status_quality
{
	REDEFINE LABEL		[status_limit];		
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans1_static_press_unit
{
	LABEL		[trans1_static_press_unit_label];
	HELP		[trans1_static_press_unit_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(2)
	{
		DEF_TRANS_SENSOR_UNIT
	}
	HANDLING	READ&WRITE;
}

VARIABLE trans1_serial_number
{
	LABEL		[trans1_serial_number_label];
	HELP		[trans1_serial_number_Help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{

		DEFAULT_VALUE	"                                " ;/* space*32 */
	}
	HANDLING	READ;
}

VARIABLE trans1_trim_pv_zero
{
	LABEL		[trans1_trim_pv_zero_label];
	HELP		[trans1_trim_pv_zero_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_trim_mode
{
	LABEL		[trans1_trim_mode_label];
	HELP		[trans1_trim_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{	0x00,	"Trim disable"		},
		{	0x01,	"Trim enable"		},
		{	0x02,	"Trim data clear"	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_ext_zero_enable
{
	LABEL		[trans1_ext_zero_enable_label];
	HELP		[trans1_ext_zero_enable_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x00;
		{	0x00,	"Enable"		},
		{	0x01,	"Disable"		}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_model
{
	LABEL		[trans1_model_label];
	HELP		[trans1_model_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32)
	{

		DEFAULT_VALUE	"EJA100                          ";
	}
	HANDLING	READ;
}

VARIABLE trans1_display_mode
{
	LABEL		[trans1_display_mode_lable];
	HELP		[trans1_display_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x01;
		{	0x01,	"1:Engineering Unit"	},
		{	0x02,	"2:% (Percentage)"		},
		{	0x03,	"3:Eng. Unit @1/10"		},
		{	0x04,	"4:Eng. Unit @1/100"	},
		{	0x05,	"5:Eng. Unit @1/1000"	},
		{	0x06,	"6:Eng. Unit @1/10000"	},
		{	0x07,	"7.Eng. Unit @1/1000000"}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_display_cycle
{
	LABEL		[trans1_display_cycle_label];
	HELP		[trans1_display_cycle_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x01;
		{	0x01,	"1"	},
		{	0x02,	"2"	},
		{	0x03,	"3"	},
		{	0x04,	"4"	},
		{	0x05,	"5"	},
		{	0x06,	"6"	},
		{	0x07,	"7"	},
		{	0x08,	"8"	},
		{	0x09,	"9"	},
		{	0x0a,	"10"}

	}
	HANDLING	READ & WRITE;
}


