/***************************************************************************************************
*  Copyright (C) Yokogawa Electric Corporation 2003,2004  All Rights Reserved.                     *
*
*  $Workfile:   YEC_EJA0101PA.inc  $
*    $Author:   ueno.madoka  $
*  $Revision:   1.4  $
*      $Date:   23 Apr 2007 22:01:22  $
*                                                                                                  *
****************************************************************************************************
*
*  PROJECT_NAME        EJA Profibus PA
*
*  FIRST_AUTHOR        Madoka Ueno
*  
*  FILE_DESCRIPTION    EJA PA PDM MENU structure
*  
*  FUNCTIONAL_MODULE_DESCRIPTION  Include file
*  
*  DICTIONARY          YEC_EJA0101PA.dct & SIEMENS standard dictionary
* 
*  RELATED_DOCUMENTS
*    Document No.        Name               Title
*---------------------------------------------------------------------------------------------------
*    STR-PBEJA-B007      M. Ueno            EJA PROFIBUS PA EDD Specification
*=================================================================================================*/
#define EJA_WRITE_LOCKING_MACRO                                         \
		ReadCommand (read_phys_write_locking);                          \
		if( ivar_value(phys_write_locking) == 0 )                       \
		{                                                               \
			PUT_MESSAGE("The device is write protected !\n Process was aborted. ");  \
			process_abort();                                            \
		}                                                               \

#define EJA_TB_TARGET_MODE_MACRO                                        \
		ReadCommand (read_trans1_target_mode);                          \
		if( ivar_value(trans1_target_mode) != 0x80 )                    \
		{                                                               \
			PUT_MESSAGE("TB Target Mode is not Out of Service. Set TB Target Mode to Out of Service.\r\n"     \
						"\r\nThis calibration is available in the following conditions:\r\n" \
						"  -TB Target Mode = Out of Service\r\n"        \
						"  -TB Trim Mode = Trim enable\r\n"             \
						"\r\nProcess was aborted. ");                   \
			process_abort();                                            \
		}                                                               \
		
#define EJA_TRIM_MODE_MACRO                                             \
		ReadCommand (read_trans1_trim_mode);                            \
		if( ivar_value(trans1_trim_mode) != 0x01 )                      \
		{                                                               \
			PUT_MESSAGE("TB Trim Mode is not Trim enable. Set Trim Mode to Trim enable. \r\n"\
						"\r\nThis calibration is available in the following conditions:\r\n" \
						"  -TB Target Mode = Out of Service\r\n"        \
						"  -TB Trim Mode = Trim enable\r\n"             \
						"\r\nProcess was aborted. ");                   \
			process_abort();                                            \
		}                                                               \
		
#define EJA_SENSOR_CALIBRATION_MACRO                                    \
		PUT_MESSAGE("Sensor Calibration is a two-point adjustment.\r\n" \
					"Lower Sensor Calibration should always be performed "\
					"before Upper Sensor Calibration in order to maintain"\
					" the pitch between the zero and 100 percent points within the calibration range.");\

/*
*********************************************************************
   IMPORT
*********************************************************************
*/
/* The following definitions must be described here for IMPORT */
#define DIA_HW_ELECTR			0x01000000		/* 0x00000001 */
#define DIA_HW_MECH				0x02000000		/* 0x00000002 */
#define DIA_TEMP_MOTOR			0x04000000		/* 0x00000004 */
#define DIA_TEMP_ELECTR			0x08000000		/* 0x00000008 */
#define DIA_MEM_CHKSUM			0x10000000		/* 0x00000010 */
#define DIA_MEASUREMENT			0x20000000		/* 0x00000020 */
#define DIA_NOT_INIT			0x40000000		/* 0x00000040 */
#define DIA_INIT_ERR			0x80000000		/* 0x00000080 */
#define DIA_ZERO_ERR			0x00010000		/* 0x00000100 */
#define DIA_SUPPLY				0x00020000		/* 0x00000200 */
#define DIA_CONF_INVAL			0x00040000		/* 0x00000400 */
#define DIA_WARMSTART			0x00080000		/* 0x00000800 */
#define DIA_COLDSTART			0x00100000		/* 0x00001000 */
#define DIA_MAINTENANCE			0x00200000		/* 0x00002000 */
#define DIA_CHARACT				0x00400000		/* 0x00004000 */
#define DIA_IDENT_VIOL			0x00800000		/* 0x00008000 */
#define EXTENSION_AVAILABLE		0x00000080		/* 0x80000000 */


IMPORT "YEC_EJA0101PAimport.inc"
{
	EVERYTHING;
	REDEFINITIONS
	{
		VARIABLE phys_diagnosis
		{
			REDEFINE TYPE		BIT_ENUMERATED (4)
			{
				DEFAULT_VALUE    0x00000000;
				{	0,					[dia_OK],					[dia_OK_help]					},
				{	DIA_HW_ELECTR,		[dia_HW_ELECTR],			[dia_HW_ELECTR_help]			},
				{	DIA_HW_MECH,		[dia_HW_MECH],				[dia_HW_MECH_help]				},
				{	DIA_MEM_CHKSUM,		[dia_MEM_CHKSUM],			[dia_MEM_CHKSUM_help]			},
				{	DIA_ZERO_ERR,		[dia_ZERO_ERR],				[dia_ZERO_ERR_help]				},
				{	DIA_COLDSTART,		[dia_COLDSTART],			[dia_COLDSTART_help]			},
				{	DIA_IDENT_VIOL,		[dia_IDENT_VIOL],			[dia_IDENT_VIOL_help]			}
				{	EXTENSION_AVAILABLE,	[dia_EXTENSION_AVAILABLE],	[dia_EXTENSION_AVAILABLE_help]	}
			}
#ifdef _V510_
			REDEFINE STYLE "MULTILINE 16 6" ;
#endif
		}
		
		VARIABLE phys_diagnosis_extension
		/* must be 4byte not 6byte. PAdl̒ʂ6byte bit enumɂPDMł܂\Ȃ */
		{
			REDEFINE TYPE		BIT_ENUMERATED (4)
			{
				DEFAULT_VALUE    0x00000000;
				{	0,					[dia_OK],							[dia_OK_help]					},
				/* octet4 */
				{	DIA_EXT_00000001,	[DIA_EXT_00000001_label],			[DIA_EXT_00000001_help]			},
				{	DIA_EXT_00000002,	[DIA_EXT_00000002_label],			[DIA_EXT_00000002_help]			},
				{	DIA_EXT_00000010,	[DIA_EXT_00000010_label],			[DIA_EXT_00000010_help]			},
				{	DIA_EXT_00000020,	[DIA_EXT_00000020_label],			[DIA_EXT_00000020_help]			},
				{	DIA_EXT_00000040,	[DIA_EXT_00000040_label],			[DIA_EXT_00000040_help]			},
				{	DIA_EXT_00000080,	[DIA_EXT_00000080_label],			[DIA_EXT_00000080_help]			},
				/* octet3 */
				{	DIA_EXT_00000200,	[DIA_EXT_00000200_label],			[DIA_EXT_00000200_help]			},
				{	DIA_EXT_00000400,	[DIA_EXT_00000400_label],			[DIA_EXT_00000400_help]			},
				{	DIA_EXT_00000800,	[DIA_EXT_00000800_label],			[DIA_EXT_00000800_help]			},
				/* octet2 */
				{	DIA_EXT_00400000,	[DIA_EXT_00400000_label],			[DIA_EXT_00400000_help]			},
				{	DIA_EXT_00800000,	[DIA_EXT_00800000_label],			[DIA_EXT_00800000_help]			},
				/* octet1 */
				{	DIA_EXT_40000000,	[DIA_EXT_40000000_label],			[DIA_EXT_40000000_help]			},
				{	DIA_EXT_01000000,	[DIA_EXT_01000000_label],			[DIA_EXT_01000000_help]			},
				{	DIA_EXT_08000000,	[DIA_EXT_08000000_label],			[DIA_EXT_08000000_help]			},
				{	DIA_EXT_02000000,	[DIA_EXT_02000000_label],			[DIA_EXT_02000000_help]			},
				{	DIA_EXT_20000000,	[DIA_EXT_20000000_label],			[DIA_EXT_20000000_help]			},
				{	DIA_EXT_10000000,	[DIA_EXT_10000000_label],			[DIA_EXT_10000000_help]			},
				{	DIA_EXT_04000000,	[DIA_EXT_04000000_label],			[DIA_EXT_04000000_help]			}
			}
#ifdef _V510_
				ADD STYLE "MULTILINE 16 16" ;
#endif
		}

		VARIABLE phys_diagnosis_extension_mask
		/* must be 4byte not 6byte. PAdl̒ʂ6byte bit enumɂPDMł܂\Ȃ */
		{
			REDEFINE TYPE		BIT_ENUMERATED (4)
			{
				DEFAULT_VALUE    0x7fc00ef3;
				/* octet4 */
				{	DIA_EXT_00000001,	[DIA_EXT_00000001_label],			[DIA_EXT_00000001_help]			},
				{	DIA_EXT_00000002,	[DIA_EXT_00000002_label],			[DIA_EXT_00000002_help]			},
				{	DIA_EXT_00000010,	[DIA_EXT_00000010_label],			[DIA_EXT_00000010_help]			},
				{	DIA_EXT_00000020,	[DIA_EXT_00000020_label],			[DIA_EXT_00000020_help]			},
				{	DIA_EXT_00000040,	[DIA_EXT_00000040_label],			[DIA_EXT_00000040_help]			},
				{	DIA_EXT_00000080,	[DIA_EXT_00000080_label],			[DIA_EXT_00000080_help]			},
				/* octet3 */
				{	DIA_EXT_00000200,	[DIA_EXT_00000200_label],			[DIA_EXT_00000200_help]			},
				{	DIA_EXT_00000400,	[DIA_EXT_00000400_label],			[DIA_EXT_00000400_help]			},
				{	DIA_EXT_00000800,	[DIA_EXT_00000800_label],			[DIA_EXT_00000800_help]			},
				/* octet2 */
				{	DIA_EXT_00400000,	[DIA_EXT_00400000_label],			[DIA_EXT_00400000_help]			},
				{	DIA_EXT_00800000,	[DIA_EXT_00800000_label],			[DIA_EXT_00800000_help]			},
				/* octet1 */
				{	DIA_EXT_40000000,	[DIA_EXT_40000000_label],			[DIA_EXT_40000000_help]			},
				{	DIA_EXT_01000000,	[DIA_EXT_01000000_label],			[DIA_EXT_01000000_help]			},
				{	DIA_EXT_08000000,	[DIA_EXT_08000000_label],			[DIA_EXT_08000000_help]			},
				{	DIA_EXT_02000000,	[DIA_EXT_02000000_label],			[DIA_EXT_02000000_help]			},
				{	DIA_EXT_20000000,	[DIA_EXT_20000000_label],			[DIA_EXT_20000000_help]			},
				{	DIA_EXT_10000000,	[DIA_EXT_10000000_label],			[DIA_EXT_10000000_help]			},
				{	DIA_EXT_04000000,	[DIA_EXT_04000000_label],			[DIA_EXT_04000000_help]			}
			}
		}

		VARIABLE phys_target_mode
		{
			REDEFINE TYPE		ENUMERATED (1)
			{
				DEFAULT_VALUE	0x08;
				{	0x08,	[mode_AUTO]				},
				{	0x80,	[mode_OUT_OF_SERVICE]	}
			}
		}

		VARIABLE phys_software_rev
		{
			REDEFINE TYPE		ASCII (16)
			{
				DEFAULT_VALUE	"R1.04";
			}
		}

		VARIABLE phys_hardware_rev
		{
			REDEFINE TYPE		ASCII (16)
			{
				DEFAULT_VALUE	"S1.01";
			}
		}

		VARIABLE phys_factory_reset
		{
			REDEFINE TYPE		ENUMERATED(2)
			{
				DEFAULT_VALUE	1;
				{ 1,				[factory_reset_PARAMS]	},
				{ 2506,				[phys_device_reset_cmd]	},
				{ 2712,				[factory_reset_ADDRESS]	}
			}
		}

		VARIABLE trans1_target_mode
		{
			REDEFINE TYPE		ENUMERATED (1)
			{
				DEFAULT_VALUE	0x08;
				{ 0x08, [mode_AUTO]           },
				{ 0x80, [mode_OUT_OF_SERVICE] }
			}
		}

		VARIABLE trans1_sensor_high_limit
		{
			REDEFINE LABEL		[trans_sensor_upper_limit_eja_label];
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE	98.0665;
			}
		}

		VARIABLE trans1_sensor_low_limit
		{
			REDEFINE LABEL		[trans_sensor_lower_limit_eja_label];
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE	-98.0665;
			}
		}

		VARIABLE trans1_cal_point_hi
		{
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE	98.0665;
			}
		}

		VARIABLE trans1_cal_min_span
		{
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE	1.96133;
			}
		}

		VARIABLE trans1_sensor_unit
		{
			REDEFINE LABEL		[trans_pres_sensor_unit_eja_label];
		}

		VARIABLE trans1_primary_value_type
		{
			REDEFINE TYPE		ENUMERATED (2)
			{
				{	0,		[trans_pres_primary_value_type_pres]	},
				{	1,		[trans_pres_primary_value_type_flow]	},
				{	2,		[trans_pres_primary_value_type_level]	},
				{	3,		[trans_pres_primary_value_type_volume]	},
				{	253,	[trans_pres_primary_value_type_special]	}
			}
		}

		VARIABLE trans1_temperature_unit
		{
			REDEFINE TYPE		ENUMERATED (2)
			{
				DEFAULT_VALUE	1001;
				{ 1001,  [unit_1001],		[unit_1001_help]		},
				{ 1002,  [unit_1002],		[unit_1002_help]		}
			}
		}

		VARIABLE trans1_secondary_value_1_value
		{
			REDEFINE LABEL		[trans_secondary_value_1_value_eja_label];
		}

		VARIABLE trans1_secondary_value_1_unit
		{
			REDEFINE LABEL         [trans_secondary_value_1_unit_eja_label];
		}

		VARIABLE trans1_scale_in_upper_value
		{
		   REDEFINE TYPE          FLOAT
			{
				DEFAULT_VALUE  100.0;
			}
		}

		VARIABLE trans1_scale_out_upper_value
		{
		   REDEFINE TYPE          FLOAT
			{
				DEFAULT_VALUE  100.0;
			}
		}

		VARIABLE func1_AI_alarm_hys
		{
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE  0.500;
//				DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI(func1_AI_alarm_hys)
			}
		}

		VARIABLE func2_AI_alarm_hys
		{
			REDEFINE TYPE		FLOAT
			{
				DEFAULT_VALUE  0.500;
//				DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC2_AI(func2_AI_alarm_hys)
			}
		}

		MENU Page_diagnosis_general
		{
			REDEFINE ITEMS
			{
				phys_tag_desc			(READ_ONLY),
				phys_device_man_id,
				phys_device_id,
				phys_device_ser_num,
				phys_software_rev,
				phys_hardware_rev,
				phys_install_date		(READ_ONLY),
				phys_write_locking		(READ_ONLY)
			}
		}

		MENU Tab_s_ident_device
		{
			REDEFINE ITEMS
			{
				phys_device_man_id,
				phys_device_id,
				phys_device_ser_num,
				phys_software_rev,
				phys_hardware_rev,
				phys_blk_profile_rev,
				phys_st_rev,
				phys_ident_number,
				phys_install_date,
				phys_soft_desc,
				trans1_serial_number
			}
		}

		MENU Tab_m_ident_device
		{
			REDEFINE ITEMS
			{
				phys_device_man_id,
				phys_device_id,
				phys_device_ser_num,
				phys_software_rev,
				phys_hardware_rev,
				phys_blk_profile_rev,
				phys_st_rev,
				phys_ident_number	(READ_ONLY),
				phys_install_date	(READ_ONLY),
				phys_soft_desc,
				trans1_serial_number
			}
		}

		MENU Tab_s_func1
		{
			REDEFINE ITEMS
			{
				func1_AI_st_rev,
				func1_AI_target_mode,
				func1_AI_actual_mode,
				func1_AI_channel,
				func1_AI_out_unit,
				func1_AI_out_unit_text,
				func1_AI_pv_ftime,
				Tab_s_func1_batch,
			/*	Tab_s_func1_pv_range, */
				Tab_s_func1_outscale,
				Tab_s_func1_limits,
				Tab_s_func1_FSafe,
				Tab_s_func1_interface
			}
		}

		MENU Tab_m_func1
		{
			REDEFINE ITEMS
			{
				func1_AI_st_rev,
				func1_AI_target_mode (READ_ONLY),
				func1_AI_actual_mode,
				func1_AI_channel	(READ_ONLY),
				func1_AI_out_unit	(READ_ONLY),
				func1_AI_out_unit_text (READ_ONLY),
				func1_AI_pv_ftime (READ_ONLY),
				Tab_s_func1_batch,
			/*	Tab_m_func1_pv_range, */
				Tab_m_func1_outscale,
				Tab_m_func1_limits,
				Tab_m_func1_FSafe,
				Tab_m_func1_interface
			}
		}

		MENU Tab_s_func2
		{
			REDEFINE ITEMS
			{
				func2_AI_st_rev,
				func2_AI_target_mode,
				func2_AI_actual_mode,
				func2_AI_channel,
				func2_AI_out_unit,
				func2_AI_out_unit_text,
				func2_AI_pv_ftime,
				Tab_s_func2_batch,
				Tab_s_func2_pv_range,
				Tab_s_func2_outscale,
				Tab_s_func2_limits,
				Tab_s_func2_FSafe,
				Tab_s_func2_interface
			}
		}

		MENU Tab_m_func2
		{
			REDEFINE ITEMS
			{
				func2_AI_st_rev,
				func2_AI_target_mode (READ_ONLY),
				func2_AI_actual_mode,
				func2_AI_channel	(READ_ONLY),
				func2_AI_out_unit	(READ_ONLY),	
				func2_AI_out_unit_text (READ_ONLY),
				func2_AI_pv_ftime (READ_ONLY),
				Tab_s_func2_batch,
				Tab_m_func2_pv_range,
				Tab_m_func2_outscale,
				Tab_m_func2_limits,
				Tab_m_func2_FSafe,
				Tab_m_func2_interface
			}
		}

		MENU Tab_s_trans1_input_meassurelimit
		{
			REDEFINE LABEL		[Tab_s_trans1_input_meassurelimit_eja_label];
			REDEFINE ITEMS
			{
				trans1_sensor_unit,
				trans1_sensor_low_limit,	
				trans1_sensor_high_limit
			}
		}

		MENU Tab_m_trans1_input_meassurelimit
		{
			REDEFINE LABEL		[Tab_s_trans1_input_meassurelimit_eja_label];
		}

		REDEFINE MENU Tab_s_trans1_input_meassurerange
		{
			LABEL		[Tab_s_trans1_input_meassurerange_eja_label];
			ITEMS
			{
				trans1_secondary_value_1_unit,
				trans1_scale_in_lower_value,
				trans1_scale_in_upper_value
			}
		}

		REDEFINE MENU Tab_m_trans1_input_meassurerange
		{
			LABEL		[Tab_s_trans1_input_meassurerange_eja_label];
			ITEMS
			{
				trans1_secondary_value_1_unit	(READ_ONLY),
				trans1_scale_in_lower_value		(READ_ONLY),
				trans1_scale_in_upper_value		(READ_ONLY)
			}
		}
	}
}






/*
*********************************************************************
   MENU Bar
*********************************************************************
*/

MENU Menu_Main_Specialist
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_Options,
		Menu_Help
	}
}

MENU Menu_Main_Maintenance
{
	LABEL		[main_menu];
	ITEMS
	{
		Menu_File,
		Menu_M_Device,
		Menu_M_View,
		Menu_M_Options,
		Menu_Help
	}
}


/*-------------------------------------------------------------------
 *    Menu: Device
 *-----------------------------------------------------------------*/


MENU Menu_S_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		std_NodeAddress,
		SEPARATOR,
		Menu_simulation,
		SEPARATOR,
        OnlineDialog_target_mode,
		OnlineDialog_trim_pv_zero,
		OnlineDialog_sensor_trim_eja,
		SEPARATOR,
		OnlineDialog_reset,
		OnlineDialog_write_locking,
        Menu_s_query_device
	}
}

MENU Menu_M_Device
{
	LABEL		[menu_Device];
	ITEMS
	{
		std_LoadinDevice,
		std_LoadinPC,
		Menu_m_query_device
	}
}

MENU Menu_simulation
{
	LABEL		[menu_dialog_simulation];
	ITEMS
	{
		OnlineDialog_simulation_func1,
        OnlineDialog_simulation_func2
	}
}

MENU OnlineDialog_target_mode
{
	LABEL		[target_mode];
	ITEMS
	{
		Page_target_mode
	}
}

MENU Page_target_mode
{
	LABEL		[target_mode];
	ITEMS
	{
		Group_phys_target_mode,
		Group_trans1_target_mode,
		Group_func1_target_mode,
		Group_func2_target_mode
	}
}

MENU Group_phys_target_mode
{
	LABEL		[physical_block_label];
	ITEMS
	{
		phys_target_mode,
		phys_actual_mode
	}
}

MENU Group_trans1_target_mode
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_target_mode,
		trans1_actual_mode
	}
}

MENU Group_func1_target_mode
{
	LABEL		FUNC1_TITLE;
	ITEMS
	{
		func1_AI_target_mode,
		func1_AI_actual_mode
	}
}

MENU Group_func2_target_mode
{
	LABEL		FUNC2_TITLE;
	ITEMS
	{
		func2_AI_target_mode,
		func2_AI_actual_mode
	}
}

MENU OnlineDialog_trim_pv_zero
{
   LABEL  "Zero Point Adjustment";
   ITEMS
   {
		Page_trim_pv_zero
   }
}

MENU Page_trim_pv_zero
{
	LABEL		"Zero Point Adjustment";
	ITEMS
	{
		trans1_target_mode,
		trans1_trim_mode,
		trans1_sensor_unit,
		trans1_sensor_low_limit,
		trans1_sensor_high_limit,
		method_set,
		Group_trim_pv_zero
		Group_trim_pv_zero_trimmed_value
	}
}

MENU Group_trim_pv_zero
{
	LABEL		"Zero Point Adjustment";
	ITEMS
	{
		trans1_trim_pv_zero	(READ_ONLY),
		SEPARATOR,
		method_trans1_trim_pv_zero,

	}
}
MENU Group_trim_pv_zero_trimmed_value
{
	LABEL		[trans_pres_trimmed_value];
	ITEMS
	{
		trans1_trimmed_value,
		SEPARATOR,
		trans1_trimmed_status_quality,
		trans1_trimmed_status_limit
	}
}

MENU OnlineDialog_sensor_trim_eja
{
	LABEL		[menu_dialog_sensor_trim];
	ITEMS
	{
		Page_cal_point_lo_eja,
		Page_cal_point_hi_eja
	}
}

MENU Page_cal_point_lo_eja
{
	LABEL		[menu_dialog_sensor_trim_cal_point_lo];
	ITEMS
	{
		trans1_target_mode,
		trans1_trim_mode,
		trans1_sensor_unit,
		trans1_sensor_low_limit,
		trans1_sensor_high_limit,
		trans1_cal_min_span,
		method_set
		Group_cal_point_lo,
		Group_cal_trimmed
	}
	PRE_READ_ACTIONS
	{
		method_read_cal_point_lo
	}
}

MENU Page_cal_point_hi_eja
{
	LABEL		[menu_dialog_sensor_trim_cal_point_hi];
	ITEMS
	{
		trans1_target_mode,
		trans1_trim_mode,
		trans1_sensor_unit,
		trans1_sensor_low_limit,
		trans1_sensor_high_limit,
		trans1_cal_min_span,
		method_set
		Group_cal_point_hi,
		Group_cal_trimmed
	}
	PRE_READ_ACTIONS
	{
		method_read_cal_point_hi
	}
}

MENU Group_cal_point_lo
{
	LABEL		[Group_s_eja_trans1_cal_point_label];
	ITEMS
	{
		dummy_trans1_cal_point_lo,
		SEPARATOR,
		method_execute_cal_point_lo
	}
}

MENU Group_cal_point_hi
{
	LABEL		[Group_s_eja_trans1_cal_point_label];
	ITEMS
	{
		dummy_trans1_cal_point_hi,
		SEPARATOR,
		method_execute_cal_point_hi
	}
}


/*-------------------------------------------------------------------
 *    Menu: View
 *-----------------------------------------------------------------*/

MENU Menu_S_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		OnlineWindow_S_alarm_func1,
		OnlineWindow_S_alarm_func2
	}
}

MENU Menu_M_alarm
{
	LABEL		[menu_dialog_alarm];
	ITEMS
	{
		OnlineWindow_M_alarm_func1,
		OnlineWindow_M_alarm_func2
	}
}

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_measure_eja,
		Page_display_func1,
		Page_display_func2
	}
}

MENU Page_display_measure_eja
{
	LABEL		[Page_display_measure_eja_label];
	ITEMS
	{
		Val_sensor_display,
		Group_display_secondary,
		Group_display_primary,
		Group_display_static_pressure,
		Group_display_temperatur
	}
}

MENU Val_sensor_display
{
	LABEL		[trans_pres_sensor_value];
	ITEMS
	{
		trans1_sensor_value
	}
}

MENU Group_display_primary
{
	LABEL		[Group_display_primary_eja_label];
	ITEMS
	{
		trans1_primary_value,
		SEPARATOR,
		trans1_primary_value_status_quality,
		trans1_primary_value_status_limit
	}
}

#ifndef NO_trans1_secondary_value_1
MENU Group_display_secondary
{
	LABEL		[Group_display_secondary_eja_label];
	ITEMS
	{
		trans1_secondary_value_1_value,
		SEPARATOR,
		trans1_secondary_value_1_status_quality,
		trans1_secondary_value_1_status_limit
	}
}
#endif

MENU Group_display_static_pressure
{
	LABEL		[Group_display_static_pressure_label];
	ITEMS
	{
		trans1_static_press_value,
		SEPARATOR,
		trans1_static_press_value_status_quality,
		trans1_static_press_value_status_limit
	}
}

MENU OnlineWindow_diagnosis
{
	LABEL		[menu_dialog_diagnosis];
	ITEMS
	{
		Page_diagnosis_general,
		Page_diagnosis_eja_diag,
		Page_diagnosis_phys_block,
		Page_diagnosis_trans_block,
		Page_diagnosis_func1,
		Page_diagnosis_func2
	}
}

MENU Page_diagnosis_trans_block
{
	LABEL		[blk_block_object_TRANSDUCER];
	ITEMS
	{
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_st_rev,
		trans1_actual_mode
	}
}

MENU Page_diagnosis_eja_diag
{
	LABEL		[Page_diagnosis_eja_diag_label];
	ITEMS
	{
		phys_diagnosis,
		phys_diagnosis_extension
	}
}


/*-------------------------------------------------------------------
 *     EJA Online Dialog Query Device -specialist
 *-----------------------------------------------------------------*/

//Device -> Query Device [Specialist]
MENU Menu_s_query_device
{
	LABEL  [query_device];
	ITEMS
	{
		OnlineDialog_s_query_pb,	/* PB */ 
		OnlineDialog_s_query_tb,	/* TB */
		OnlineDialog_s_query_ai,	/* AI */
		OnlineDialog_s_query_ai2	/* AI2*/
	}
	
}

//Device -> Query Device -> Physical Block [Specialist]
MENU OnlineDialog_s_query_pb
{
	LABEL	[blk_block_object_PHYSICAL];
	ITEMS
	{
		Page_s_query_pb_1,
		Page_s_query_pb_2,
		Page_s_query_pb_3
	}
}


//Device -> Query Device -> Physical Block -> Index16-23 [Specialist]
MENU Page_s_query_pb_1
{
	LABEL	[query_phys_1];
	ITEMS
	{
		phys_blk_reserve,					/* Index16 */
		phys_blk_object,					
		phys_blk_parent_class,				
		phys_blk_class,						
		phys_blk_dd_reference,				
		phys_blk_dd_rev,					
		phys_blk_profile,					
		phys_blk_profile_rev,				
		phys_blk_execution_time,			
		phys_blk_num_parameters,			
		phys_blk_index_view_1,				
		phys_blk_num_view_lists,			
		SEPARATOR,
		phys_st_rev,						/* Index17 */
		phys_tag_desc,						/* Index18 */
		phys_strategy,						/* Index19 */
		phys_alert_key,						/* Index20 */
		phys_target_mode,					/* Index21 */
		phys_actual_mode,					/* Index22 */
		phys_permitted_mode,				
		phys_normal_mode,					
		phys_current_state_alarm_sum,		/* Index23 */
		phys_unacknowledged_state_alarm_sum,
		phys_unreported_state_alarm_sum,	
		phys_disabled_state_alarm_sum,		
		method_set
	}
	
}

//Device -> Query Device -> Physical Block -> Index24- [Specialist]
MENU Page_s_query_pb_2
{
	LABEL	[query_phys_2];
	ITEMS
	{
		phys_software_rev,					/* Index24 */
		phys_hardware_rev,					/* Index25 */
		phys_device_man_id,					/* Index26 */
		phys_device_id,						/* Index27 */
		phys_device_ser_num,				/* Index28 */
		phys_diagnosis,						/* Index29 */
		phys_diagnosis_extension,			/* Index30 */
		phys_diagnosis_mask,				/* Index31 */
		phys_diagnosis_extension_mask,		/* Index32 */
		method_set
	}
}

MENU Page_s_query_pb_3
{
	LABEL	[query_phys_3];
	ITEMS
	{
		phys_device_certification,			/* Index33 */
		phys_write_locking,					/* Index34 */
		phys_factory_reset,					/* Index35 */
		phys_descriptor,					/* Index36 */
		phys_message,						/* Index37 */
		phys_install_date,					/* Index38 */
//		phys_local_operation_enable,		/* Index39 */
		phys_ident_number,					/* Index40 */
		phys_hw_write_protection,			/* Index41 */
		phys_soft_desc,						/* Index49 */
		phys_set_address,					/* Index50 */
		method_set
	}
}

//Device -> Query Device -> Transducer Block [Specialist]
MENU OnlineDialog_s_query_tb
{
	LABEL	TRANS1_TITLE;
	ITEMS
	{
		Page_s_query_tb_1,
		Page_s_query_tb_2,
		Page_s_query_tb_3,
		Page_s_query_tb_4
	}
}

//Device -> Query Device -> Transducer Block -> index16-23 [Specialist]
MENU Page_s_query_tb_1
{
	LABEL	[query_tb_1];
	ITEMS
	{
		trans1_blk_reserve,					/* Index16 */
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_blk_execution_time,
		trans1_blk_num_parameters,
		trans1_blk_index_view_1,
		trans1_blk_num_view_lists,
		trans1_st_rev,						/* Index17 */
		trans1_tag_desc,					/* Index18 */
		trans1_strategy,					/* Index19 */
		trans1_alert_key,					/* Index20 */
		trans1_target_mode,					/* Index21 */
		trans1_actual_mode,					/* Index22 */
		trans1_permitted_mode,
		trans1_normal_mode,
		trans1_current_state_alarm_sum,		/* Index23 */
		trans1_unacknowledged_state_alarm_sum,
		trans1_unreported_state_alarm_sum,
		trans1_disabled_state_alarm_sum,
		method_set
	}
}

//Device -> Query Device -> Transducer Block -> index24-35 [Specialist]
MENU Page_s_query_tb_2
{
	LABEL	[query_tb_2];
	ITEMS
	{
		Group_s_eja_trans1_sensor_value,			/* index24 */
		Group_s_eja_trans1_sensor_limit,		
		Group_s_eja_trans1_cal_point,			/* index27 */
		Group_s_eja_trans1_sensor_unit			/* index30 */
		Group_s_eja_trans1_trimmed_value,		/* index31 */
		trans1_sensor_type,						/* index32 */
		Group_s_eja_trans1_primary_value,
		trans1_primary_value_type,				/* index35 */
		method_set
	}
}

//Device -> Query Device -> Transducer Block -> index45-76 [Specialist]
MENU Page_s_query_tb_3
{
	LABEL	[query_tb_3];
	ITEMS
	{
		Group_s_eja_trans1_temperature_value,
		Group_s_eja_trans1_secondary_value_1_value,/* index45 */
		trans1_lin_type,						/* index49 */
		Group_s_eja_trans1_scale_in,			/* index50 */
		Group_s_eja_trans1_scale_out,			/* index51 */
		trans1_low_flow_cut_off,				/* index52 */
		trans1_flow_lin_sqrt_point,				/* index53 */
		Group_s_eja_trans1_static_press_value,
		method_set
	}
}

MENU Page_s_query_tb_4
{
	LABEL	[query_tb_4];
	ITEMS
	{
		trans1_serial_number,					/* index77 */
		trans1_trim_pv_zero,					/* index78 */
		trans1_trim_mode,						/* index79 */
		trans1_ext_zero_enable,					/* index80 */
		trans1_model,							/* index81 */
		trans1_display_mode,					/* index82 */
		trans1_display_cycle,					/* index83 */
		method_set
	}
}

MENU Group_s_eja_trans1_sensor_value
{
	LABEL	[Group_eja_trans1_sensor_value_label];
	ITEMS
	{
		trans1_sensor_value						/* index24 */
	}
}

MENU Group_s_eja_trans1_sensor_limit
{
	LABEL	[Group_s_trans1_eja_sensor_limit_label];
	ITEMS
	{
		trans1_sensor_high_limit,				/* index25 */
		trans1_sensor_low_limit				/* index26 */
	}
}

MENU Group_s_eja_trans1_cal_point
{
	LABEL	[Group_s_eja_trans1_cal_point_label];
	ITEMS
	{
		trans1_cal_point_hi,					/* index27 */
		trans1_cal_point_lo,					/* index28 */
		trans1_cal_min_span						/* index29 */
	}
}

MENU Group_s_eja_trans1_sensor_unit
{
	LABEL	[Group_eja_trans1_sensor_unit_label];
	ITEMS
	{
		trans1_sensor_unit						/* index30 */
	}
}

MENU Group_s_eja_trans1_primary_value
{
	LABEL	[Group_s_eja_trans1_primary_value_label];
	ITEMS
	{
		trans1_primary_value,					/* index33 */
		trans1_primary_value_status_quality,	
		trans1_primary_value_status_limit,		
		trans1_primary_value_unit				/* index34 */
	}
}

MENU Group_s_eja_trans1_trimmed_value
{
	LABEL	[Group_s_eja_trans1_trimmed_value_label];
	ITEMS
	{
		trans1_trimmed_value,					/* index31 */
		trans1_trimmed_status_quality,			
		trans1_trimmed_status_limit			
	}
}

MENU Group_s_eja_trans1_secondary_value_1_value
{
	LABEL	[Group_s_eja_trans1_secondary_value_1_value_label];
	ITEMS
	{
		trans1_secondary_value_1_value,			/* index45 */
		trans1_secondary_value_1_status_quality,
		trans1_secondary_value_1_status_limit,	
		trans1_secondary_value_1_unit			/* index46 */
	}
}

MENU Group_s_eja_trans1_scale_in
{
	LABEL	[Tab_s_trans1_input_meassurerange_eja_label];
	ITEMS
	{
		trans1_scale_in_upper_value,			/* index50 */
		trans1_scale_in_lower_value			
	}
}

MENU Group_s_eja_trans1_scale_out
{
	LABEL	[Group_s_eja_trans1_scale_out_label];
	ITEMS
	{
		trans1_scale_out_upper_value,			/* index51 */
		trans1_scale_out_lower_value			
	}
}

MENU Group_s_eja_trans1_temperature_value
{
	LABEL	[Group_s_eja_trans1_temperature_value_label];
	ITEMS
	{
		trans1_temperature_value,				/* index43 */
		trans1_temperature_status_quality,		
		trans1_temperature_status_limit,		
		trans1_temperature_unit				/* index44 */
	}
}

MENU Group_s_eja_trans1_static_press_value
{
	LABEL	[Group_s_eja_trans1_static_press_value_label];
	ITEMS
	{
		trans1_static_press_value,				/* index75 */
		trans1_static_press_value_status_quality,
		trans1_static_press_value_status_limit,	
		trans1_static_press_unit				/* index76 */
	}
}

//Device -> Query Device -> Analog Input [Specialist]
MENU OnlineDialog_s_query_ai
{
	LABEL	FUNC1_TITLE;
	ITEMS
	{
		Page_s_query_ai_1,
		Page_s_query_ai_2,
		Page_s_query_ai_3,
		Page_s_query_ai_4
	}
}

//Device -> Query Device -> Analog Input index16-22 [Specialist]
MENU Page_s_query_ai_1
{
	LABEL	[query_ai_1];
	ITEMS
	{
		func1_AI_blk_reserve,				/* Index16 */
		func1_AI_blk_object,
		func1_AI_blk_parent_class,
		func1_AI_blk_class,
		func1_AI_blk_dd_reference,
		func1_AI_blk_dd_rev,
		func1_AI_blk_profile,
		func1_AI_blk_profile_rev,
		func1_AI_blk_execution_time,
		func1_AI_blk_num_parameters,
		func1_AI_blk_index_view_1,
		func1_AI_blk_num_view_lists,
		SEPARATOR,
		func1_AI_st_rev,					/* Index17 */
		func1_AI_tag_desc,					/* Index18 */
		func1_AI_strategy,					/* Index19 */
		func1_AI_alert_key,					/* Index20 */
		func1_AI_target_mode,				/* Index21 */
		func1_AI_actual_mode,				/* Index22 */
		func1_AI_permitted_mode,			
		func1_AI_normal_mode,				
		method_set
	}
}

//Device -> Query Device -> Analog Input index23-28 [Specialist]
MENU Page_s_query_ai_2
{
	LABEL	[query_ai_2];
	ITEMS
	{
		func1_AI_current_state_alarm_sum,	/* Index23 */
		func1_AI_unacknowledged_state_alarm_sum,
		func1_AI_unreported_state_alarm_sum,
		func1_AI_disabled_state_alarm_sum,
		SEPARATOR,
		func1_AI_batch_id,					/* Index24 */
		func1_AI_batch_unit,
		func1_AI_batch_operation,
		func1_AI_batch_phase,
		Group_s_func1_ai_out,				/* Index26 */
		Group_s_func1_ai_pv_scale,			/* Index27 */
		Group_s_func1_ai_out_scale,			/* Index28 */
		method_set
	}
}

MENU Group_s_func1_ai_out
{
	LABEL	[func_out_value];
	ITEMS
	{
		func1_AI_out_value,
		func1_AI_out_status_quality,
		func1_AI_out_status_limit
	}
}

MENU Group_s_func1_ai_pv_scale
{
	LABEL	[menu_input_measwindow];
	ITEMS
	{
		func1_AI_pv_upper_range_value,
		func1_AI_pv_lower_range_value
	}
}


MENU Group_s_func1_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func1_AI_out_upper_range_value,
		func1_AI_out_lower_range_value,
		func1_AI_out_unit,
		func1_AI_out_decimal_point
	}
}

//Device -> Query Device -> Analog Input index29-49 [Specialist]
MENU Page_s_query_ai_3
{
	LABEL	[query_ai_3];
	ITEMS
	{
		func1_AI_lin_type,					/* Index29 */
		func1_AI_channel,					/* Index30 */
		func1_AI_pv_ftime,					/* Index32 */
		func1_AI_FSafeType,					/* Index33 */
		func1_AI_FSafeValue,				/* Index34 */
		func1_AI_alarm_hys,					/* Index35 */
		func1_AI_hi_hi_lim,					/* Index37 */
		func1_AI_hi_lim,					/* Index39 */
		func1_AI_lo_lim,					/* Index41 */
		func1_AI_lo_lo_lim,					/* Index43 */
		SEPARATOR,
		Group_s_func1_ai_hi_hi_alm,			/* Index46 */
		Group_s_func1_ai_hi_alm,			/* Index47 */
		Group_s_func1_ai_lo_alm,			/* Index48 */
		Group_s_func1_ai_lo_lo_alm,			/* Index49 */
		method_set
	}
}

MENU Group_s_func1_ai_hi_hi_alm
{
	LABEL	[limit_hi_hi];
	ITEMS
	{
		func1_AI_hi_hi_alm_unacknowledged,
		func1_AI_hi_hi_alm_state,
		func1_AI_hi_hi_alm_time_stamp,
		func1_AI_hi_hi_alm_subcode,
		func1_AI_hi_hi_alm_value
	}
}


MENU Group_s_func1_ai_hi_alm
{
	LABEL	[limit_hi];
	ITEMS
	{
		func1_AI_hi_alm_unacknowledged,
		func1_AI_hi_alm_state,
		func1_AI_hi_alm_time_stamp,
		func1_AI_hi_alm_subcode,
		func1_AI_hi_alm_value
	}
}

MENU Group_s_func1_ai_lo_alm
{
	LABEL	[limit_lo];
	ITEMS
	{
		func1_AI_lo_alm_unacknowledged,
		func1_AI_lo_alm_state,
		func1_AI_lo_alm_time_stamp,
		func1_AI_lo_alm_subcode,
		func1_AI_lo_alm_value
	}
}


MENU Group_s_func1_ai_lo_lo_alm
{
	LABEL	[limit_lo_lo];
	ITEMS
	{
		func1_AI_lo_lo_alm_unacknowledged,
		func1_AI_lo_lo_alm_state,
		func1_AI_lo_lo_alm_time_stamp,
		func1_AI_lo_lo_alm_subcode,
		func1_AI_lo_lo_alm_value
	}
}

//Device -> Query Device -> Analog Input index50- [Specialist]
MENU Page_s_query_ai_4
{
	LABEL	[query_ai_4];
	ITEMS
	{
		Group_s_func1_ai_simulate,			/* Index50 */
		func1_AI_out_unit_text,				/* Index52 */
		method_set
	}
}

MENU Group_s_func1_ai_simulate
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func1_AI_simulate_status_quality,
		func1_AI_simulate_status_limit
		func1_AI_simulate_value,
		func1_AI_simulation_enabled
	}
}


//Device -> Query Device -> Analog Input [Specialist]
MENU OnlineDialog_s_query_ai2
{
	LABEL	FUNC2_TITLE;
	ITEMS
	{
		Page_s_query_ai2_1,
		Page_s_query_ai2_2,
		Page_s_query_ai2_3,
		Page_s_query_ai2_4
	}
}

//Device -> Query Device -> Analog Input index16-22 [Specialist]
MENU Page_s_query_ai2_1
{
	LABEL	[query_ai_1];
	ITEMS
	{
		func2_AI_blk_reserve,				/* Index16 */
		func2_AI_blk_object,
		func2_AI_blk_parent_class,
		func2_AI_blk_class,
		func2_AI_blk_dd_reference,
		func2_AI_blk_dd_rev,
		func2_AI_blk_profile,
		func2_AI_blk_profile_rev,
		func2_AI_blk_execution_time,
		func2_AI_blk_num_parameters,
		func2_AI_blk_index_view_1,
		func2_AI_blk_num_view_lists,
		SEPARATOR,
		func2_AI_st_rev,					/* Index17 */
		func2_AI_tag_desc,					/* Index18 */
		func2_AI_strategy,					/* Index19 */
		func2_AI_alert_key,					/* Index20 */
		func2_AI_target_mode,				/* Index21 */
		func2_AI_actual_mode,				/* Index22 */
		func2_AI_permitted_mode,			
		func2_AI_normal_mode,				
		method_set
	}
}

//Device -> Query Device -> Analog Input index23-28 [Specialist]
MENU Page_s_query_ai2_2
{
	LABEL	[query_ai_2];
	ITEMS
	{
		func2_AI_current_state_alarm_sum,	/* Index23 */
		func2_AI_unacknowledged_state_alarm_sum,
		func2_AI_unreported_state_alarm_sum,
		func2_AI_disabled_state_alarm_sum,
		SEPARATOR,
		func2_AI_batch_id,					/* Index24 */
		func2_AI_batch_unit,
		func2_AI_batch_operation,
		func2_AI_batch_phase,
		Group_s_func2_ai_out,				/* Index26 */
		Group_s_func2_ai_pv_scale,			/* Index27 */
		Group_s_func2_ai_out_scale,			/* Index28 */
		method_set
	}
}

MENU Group_s_func2_ai_out
{
	LABEL	[func_out_value];
	ITEMS
	{
		func2_AI_out_value,
		func2_AI_out_status_quality,
		func2_AI_out_status_limit
	}
}

MENU Group_s_func2_ai_pv_scale
{
	LABEL	[menu_input_measwindow];
	ITEMS
	{
		func2_AI_pv_upper_range_value,
		func2_AI_pv_lower_range_value
	}
}


MENU Group_s_func2_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func2_AI_out_upper_range_value,
		func2_AI_out_lower_range_value,
		func2_AI_out_unit,
		func2_AI_out_decimal_point
	}
}

//Device -> Query Device -> Analog Input index29-49 [Specialist]
MENU Page_s_query_ai2_3
{
	LABEL	[query_ai_3];
	ITEMS
	{
		func2_AI_lin_type,					/* Index29 */
		func2_AI_channel,					/* Index30 */
		func2_AI_pv_ftime,					/* Index32 */
		func2_AI_FSafeType,					/* Index33 */
		func2_AI_FSafeValue,				/* Index34 */
		func2_AI_alarm_hys,					/* Index35 */
		func2_AI_hi_hi_lim,					/* Index37 */
		func2_AI_hi_lim,					/* Index39 */
		func2_AI_lo_lim,					/* Index41 */
		func2_AI_lo_lo_lim,					/* Index43 */
		SEPARATOR,
		Group_s_func2_ai_hi_hi_alm,			/* Index46 */
		Group_s_func2_ai_hi_alm,			/* Index47 */
		Group_s_func2_ai_lo_alm,			/* Index48 */
		Group_s_func2_ai_lo_lo_alm,			/* Index49 */
		method_set
	}
}

MENU Group_s_func2_ai_hi_hi_alm
{
	LABEL	[limit_hi_hi];
	ITEMS
	{
		func2_AI_hi_hi_alm_unacknowledged,
		func2_AI_hi_hi_alm_state,
		func2_AI_hi_hi_alm_time_stamp,
		func2_AI_hi_hi_alm_subcode,
		func2_AI_hi_hi_alm_value
	}
}


MENU Group_s_func2_ai_hi_alm
{
	LABEL	[limit_hi];
	ITEMS
	{
		func2_AI_hi_alm_unacknowledged,
		func2_AI_hi_alm_state,
		func2_AI_hi_alm_time_stamp,
		func2_AI_hi_alm_subcode,
		func2_AI_hi_alm_value
	}
}

MENU Group_s_func2_ai_lo_alm
{
	LABEL	[limit_lo];
	ITEMS
	{
		func2_AI_lo_alm_unacknowledged,
		func2_AI_lo_alm_state,
		func2_AI_lo_alm_time_stamp,
		func2_AI_lo_alm_subcode,
		func2_AI_lo_alm_value
	}
}

MENU Group_s_func2_ai_lo_lo_alm
{
	LABEL	[limit_lo_lo];
	ITEMS
	{
		func2_AI_lo_lo_alm_unacknowledged,
		func2_AI_lo_lo_alm_state,
		func2_AI_lo_lo_alm_time_stamp,
		func2_AI_lo_lo_alm_subcode,
		func2_AI_lo_lo_alm_value
	}
}

//Device -> Query Device -> Analog Input index50- [Specialist]
MENU Page_s_query_ai2_4
{
	LABEL	[query_ai_4];
	ITEMS
	{
		Group_s_func2_ai_simulate,			/* Index50 */
		func2_AI_out_unit_text,				/* Index52 */
		method_set
	}
}

MENU Group_s_func2_ai_simulate
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func2_AI_simulate_status_quality,
		func2_AI_simulate_status_limit
		func2_AI_simulate_value,
		func2_AI_simulation_enabled
	}
}

/*-------------------------------------------------------------------
 *     EJA Online Dialog Query Device -maintenance
 *-----------------------------------------------------------------*/

//Device -> Query Device [Maintenance]
MENU Menu_m_query_device
{
	LABEL  [query_device];
	ITEMS
	{
		OnlineDialog_m_query_pb,	/* PB */ 
		OnlineDialog_m_query_tb,	/* TB */
		OnlineDialog_m_query_ai,	/* AI */
		OnlineDialog_m_query_ai2	/* AI2*/
	}
	
}

//Device -> Query Device -> Physical Block
MENU OnlineDialog_m_query_pb
{
	LABEL	[blk_block_object_PHYSICAL];
	ITEMS
	{
		Page_m_query_pb_1,
		Page_m_query_pb_2,
		Page_m_query_pb_3
	}
}


//Device -> Query Device -> Physical Block -> Index16-23
MENU Page_m_query_pb_1
{
	LABEL	[query_phys_1];
	ITEMS
	{
		phys_blk_reserve,					/* Index16 */
		phys_blk_object,					
		phys_blk_parent_class,				
		phys_blk_class,						
		phys_blk_dd_reference,				
		phys_blk_dd_rev,					
		phys_blk_profile,					
		phys_blk_profile_rev,				
		phys_blk_execution_time,			
		phys_blk_num_parameters,			
		phys_blk_index_view_1,				
		phys_blk_num_view_lists,			
		SEPARATOR,
		phys_st_rev,						/* Index17 */
		phys_tag_desc	(READ_ONLY),		/* Index18 */
		phys_strategy	(READ_ONLY),		/* Index19 */
		phys_alert_key	(READ_ONLY),		/* Index20 */
		phys_target_mode(READ_ONLY),		/* Index21 */
		phys_actual_mode,					/* Index22 */
		phys_permitted_mode,				
		phys_normal_mode,					
		phys_current_state_alarm_sum,		/* Index23 */
		phys_unacknowledged_state_alarm_sum,
		phys_unreported_state_alarm_sum,	
		phys_disabled_state_alarm_sum,		
		method_set
	}
	
}

//Device -> Query Device -> Physical Block -> Index24- 
MENU Page_m_query_pb_2
{
	LABEL	[query_phys_2];
	ITEMS
	{
		phys_software_rev,					/* Index24 */
		phys_hardware_rev,					/* Index25 */
		phys_device_man_id,					/* Index26 */
		phys_device_id,						/* Index27 */
		phys_device_ser_num,				/* Index28 */
		phys_diagnosis,						/* Index29 */
		phys_diagnosis_extension,			/* Index30 */
		phys_diagnosis_mask,				/* Index31 */
		phys_diagnosis_extension_mask,		/* Index32 */
		method_set
	}
}

MENU Page_m_query_pb_3
{
	LABEL	[query_phys_3];
	ITEMS
	{
		phys_device_certification,			/* Index33 */
		phys_write_locking	(READ_ONLY),	/* Index34 */
		phys_factory_reset	(READ_ONLY),	/* Index35 */
		phys_descriptor,					/* Index36 */
		phys_message,						/* Index37 */
		phys_install_date	(READ_ONLY),	/* Index38 */
//		phys_local_operation_enable,		/* Index39 */
		phys_ident_number	(READ_ONLY),	/* Index40 */
		phys_hw_write_protection,			/* Index41 */
		phys_soft_desc,						/* Index49 */
		phys_set_address	(READ_ONLY),	/* Index50 */
		method_set
	}
}

//Device -> Query Device -> Transducer Block[Maintenance]
MENU OnlineDialog_m_query_tb
{
	LABEL	TRANS1_TITLE;
	ITEMS
	{
		Page_m_query_tb_1,
		Page_m_query_tb_2,
		Page_m_query_tb_3,
		Page_m_query_tb_4
	}
}

//Device -> Query Device -> Transducer Block -> index16-23
MENU Page_m_query_tb_1
{
	LABEL	[query_tb_1];
	ITEMS
	{
		trans1_blk_reserve,					/* Index16 */
		trans1_blk_object,
		trans1_blk_parent_class,
		trans1_blk_class,
		trans1_blk_dd_reference,
		trans1_blk_dd_rev,
		trans1_blk_profile,
		trans1_blk_profile_rev,
		trans1_blk_execution_time,
		trans1_blk_num_parameters,
		trans1_blk_index_view_1,
		trans1_blk_num_view_lists,
		trans1_st_rev,						/* Index17 */
		trans1_tag_desc		(READ_ONLY),	/* Index18 */
		trans1_strategy		(READ_ONLY),	/* Index19 */
		trans1_alert_key	(READ_ONLY),	/* Index20 */
		trans1_target_mode	(READ_ONLY),	/* Index21 */
		trans1_actual_mode,					/* Index22 */
		trans1_permitted_mode,
		trans1_normal_mode,
		trans1_current_state_alarm_sum,		/* Index23 */
		trans1_unacknowledged_state_alarm_sum,
		trans1_unreported_state_alarm_sum,
		trans1_disabled_state_alarm_sum,
		method_set
	}
}

//Device -> Query Device -> Transducer Block -> index24-35
MENU Page_m_query_tb_2
{
	LABEL	[query_tb_2];
	ITEMS
	{
		Group_m_eja_trans1_sensor_value,		/* index24 */
		Group_m_eja_trans1_sensor_limit,		
		Group_m_eja_trans1_cal_point,			/* index27 */
		Group_m_eja_trans1_sensor_unit			/* index30 */
		Group_m_eja_trans1_trimmed_value,		/* index31 */
		trans1_sensor_type,						/* index32 */
		Group_m_eja_trans1_primary_value,
		trans1_primary_value_type	(READ_ONLY),/* index35 */
		method_set
	}
}

//Device -> Query Device -> Transducer Block -> index45-76
MENU Page_m_query_tb_3
{
	LABEL	[query_tb_3];
	ITEMS
	{
		Group_m_eja_trans1_temperature_value,
		Group_m_eja_trans1_secondary_value_1_value,/* index45 */
		trans1_lin_type	(READ_ONLY),			/* index49 */
		Group_m_eja_trans1_scale_in,			/* index50 */
		Group_m_eja_trans1_scale_out,			/* index51 */
		trans1_low_flow_cut_off	(READ_ONLY),	/* index52 */
		trans1_flow_lin_sqrt_point	(READ_ONLY),/* index53 */
		Group_m_eja_trans1_static_press_value,
		method_set
	}
}

MENU Page_m_query_tb_4
{
	LABEL	[query_tb_4];
	ITEMS
	{
		trans1_serial_number,					/* index77 */
		trans1_trim_pv_zero	(READ_ONLY),		/* index78 */
		trans1_trim_mode	(READ_ONLY),		/* index79 */
		trans1_ext_zero_enable	(READ_ONLY),	/* index80 */
		trans1_model,							/* index81 */
		trans1_display_mode	(READ_ONLY),		/* index82 */
		trans1_display_cycle	(READ_ONLY),	/* index83 */
		method_set
	}
}

MENU Group_m_eja_trans1_sensor_value
{
	LABEL	[Group_eja_trans1_sensor_value_label];
	ITEMS
	{
		trans1_sensor_value						/* index24 */
	}
}

MENU Group_m_eja_trans1_sensor_limit
{
	LABEL	[Group_s_trans1_eja_sensor_limit_label];
	ITEMS
	{
		trans1_sensor_high_limit,				/* index25 */
		trans1_sensor_low_limit					/* index26 */
	}
}

MENU Group_m_eja_trans1_cal_point
{
	LABEL	[Group_s_eja_trans1_cal_point_label];
	ITEMS
	{
		trans1_cal_point_hi	(READ_ONLY),		/* index27 */
		trans1_cal_point_lo	(READ_ONLY),		/* index28 */
		trans1_cal_min_span						/* index29 */
	}
}

MENU Group_m_eja_trans1_sensor_unit
{
	LABEL	[Group_eja_trans1_sensor_unit_label];
	ITEMS
	{
		trans1_sensor_unit	(READ_ONLY)			/* index30 */
	}
}

MENU Group_m_eja_trans1_primary_value
{
	LABEL	[Group_s_eja_trans1_primary_value_label];
	ITEMS
	{
		trans1_primary_value,					/* index33 */
		trans1_primary_value_status_quality,	
		trans1_primary_value_status_limit,		
		trans1_primary_value_unit	(READ_ONLY)	/* index34 */
	}
}

MENU Group_m_eja_trans1_trimmed_value
{
	LABEL	[Group_s_eja_trans1_trimmed_value_label];
	ITEMS
	{
		trans1_trimmed_value,					/* index31 */
		trans1_trimmed_status_quality,			
		trans1_trimmed_status_limit			
	}
}

MENU Group_m_eja_trans1_secondary_value_1_value
{
	LABEL	[Group_s_eja_trans1_secondary_value_1_value_label];
	ITEMS
	{
		trans1_secondary_value_1_value,			   /* index45 */
		trans1_secondary_value_1_status_quality,
		trans1_secondary_value_1_status_limit,	
		trans1_secondary_value_1_unit	(READ_ONLY)/* index46 */
	}
}

MENU Group_m_eja_trans1_scale_in
{
	LABEL	[Tab_s_trans1_input_meassurerange_eja_label];
	ITEMS
	{
		trans1_scale_in_upper_value	(READ_ONLY),/* index50 */
		trans1_scale_in_lower_value	(READ_ONLY)
	}
}

MENU Group_m_eja_trans1_scale_out
{
	LABEL	[Group_s_eja_trans1_scale_out_label];
	ITEMS
	{
		trans1_scale_out_upper_value	(READ_ONLY),/* index51 */
		trans1_scale_out_lower_value	(READ_ONLY)
	}
}

MENU Group_m_eja_trans1_temperature_value
{
	LABEL	[Group_s_eja_trans1_temperature_value_label];
	ITEMS
	{
		trans1_temperature_value,				/* index43 */
		trans1_temperature_status_quality,		
		trans1_temperature_status_limit,		
		trans1_temperature_unit	(READ_ONLY)		/* index44 */
	}
}

MENU Group_m_eja_trans1_static_press_value
{
	LABEL	[Group_s_eja_trans1_static_press_value_label];
	ITEMS
	{
		trans1_static_press_value,				/* index75 */
		trans1_static_press_value_status_quality,
		trans1_static_press_value_status_limit,	
		trans1_static_press_unit	(READ_ONLY)	/* index76 */
	}
}

//Device -> Query Device -> Analog Input [Specialist]
MENU OnlineDialog_m_query_ai
{
	LABEL	FUNC1_TITLE;
	ITEMS
	{
		Page_m_query_ai_1,
		Page_m_query_ai_2,
		Page_m_query_ai_3,
		Page_m_query_ai_4
	}
}

//Device -> Query Device -> Analog Input index16-22 
MENU Page_m_query_ai_1
{
	LABEL	[query_ai_1];
	ITEMS
	{
		func1_AI_blk_reserve,				/* Index16 */
		func1_AI_blk_object,
		func1_AI_blk_parent_class,
		func1_AI_blk_class,
		func1_AI_blk_dd_reference,
		func1_AI_blk_dd_rev,
		func1_AI_blk_profile,
		func1_AI_blk_profile_rev,
		func1_AI_blk_execution_time,
		func1_AI_blk_num_parameters,
		func1_AI_blk_index_view_1,
		func1_AI_blk_num_view_lists,
		SEPARATOR,
		func1_AI_st_rev,					/* Index17 */
		func1_AI_tag_desc	(READ_ONLY),	/* Index18 */
		func1_AI_strategy	(READ_ONLY),	/* Index19 */
		func1_AI_alert_key	(READ_ONLY),	/* Index20 */
		func1_AI_target_mode(READ_ONLY),	/* Index21 */
		func1_AI_actual_mode,				/* Index22 */
		func1_AI_permitted_mode,			
		func1_AI_normal_mode,				
		method_set
	}
}

//Device -> Query Device -> Analog Input index23-28
MENU Page_m_query_ai_2
{
	LABEL	[query_ai_2];
	ITEMS
	{
		func1_AI_current_state_alarm_sum,	/* Index23 */
		func1_AI_unacknowledged_state_alarm_sum,
		func1_AI_unreported_state_alarm_sum,
		func1_AI_disabled_state_alarm_sum,
		SEPARATOR,
		func1_AI_batch_id,					/* Index24 */
		func1_AI_batch_unit,
		func1_AI_batch_operation,
		func1_AI_batch_phase,
		Group_m_func1_ai_out,				/* Index26 */
		Group_m_func1_ai_pv_scale,			/* Index27 */
		Group_m_func1_ai_out_scale,			/* Index28 */
		method_set
	}
}

MENU Group_m_func1_ai_out
{
	LABEL	[func_out_value];
	ITEMS
	{
		func1_AI_out_value			(READ_ONLY),
		func1_AI_out_status_quality	(READ_ONLY),
		func1_AI_out_status_limit	(READ_ONLY)
	}
}

MENU Group_m_func1_ai_pv_scale
{
	LABEL	[menu_input_measwindow];
	ITEMS
	{
		func1_AI_pv_upper_range_value	(READ_ONLY),
		func1_AI_pv_lower_range_value	(READ_ONLY)
	}
}


MENU Group_m_func1_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func1_AI_out_upper_range_value	(READ_ONLY),
		func1_AI_out_lower_range_value	(READ_ONLY),
		func1_AI_out_unit				(READ_ONLY),
		func1_AI_out_decimal_point		(READ_ONLY)
	}
}

//Device -> Query Device -> Analog Input index29-49 
MENU Page_m_query_ai_3
{
	LABEL	[query_ai_3];
	ITEMS
	{
		func1_AI_lin_type	(READ_ONLY),	/* Index29 */
		func1_AI_channel	(READ_ONLY),	/* Index30 */
		func1_AI_pv_ftime	(READ_ONLY),	/* Index32 */
		func1_AI_FSafeType	(READ_ONLY),	/* Index33 */
		func1_AI_FSafeValue	(READ_ONLY),	/* Index34 */
		func1_AI_alarm_hys	(READ_ONLY),	/* Index35 */
		func1_AI_hi_hi_lim	(READ_ONLY),	/* Index37 */
		func1_AI_hi_lim		(READ_ONLY),	/* Index39 */
		func1_AI_lo_lim		(READ_ONLY),	/* Index41 */
		func1_AI_lo_lo_lim	(READ_ONLY),	/* Index43 */
		SEPARATOR,
		Group_m_func1_ai_hi_hi_alm,			/* Index46 */
		Group_m_func1_ai_hi_alm,			/* Index47 */
		Group_m_func1_ai_lo_alm,			/* Index48 */
		Group_m_func1_ai_lo_lo_alm,			/* Index49 */
		method_set
	}
}

MENU Group_m_func1_ai_hi_hi_alm
{
	LABEL	[limit_hi_hi];
	ITEMS
	{
		func1_AI_hi_hi_alm_unacknowledged,
		func1_AI_hi_hi_alm_state,
		func1_AI_hi_hi_alm_time_stamp,
		func1_AI_hi_hi_alm_subcode,
		func1_AI_hi_hi_alm_value
	}
}


MENU Group_m_func1_ai_hi_alm
{
	LABEL	[limit_hi];
	ITEMS
	{
		func1_AI_hi_alm_unacknowledged,
		func1_AI_hi_alm_state,
		func1_AI_hi_alm_time_stamp,
		func1_AI_hi_alm_subcode,
		func1_AI_hi_alm_value
	}
}

MENU Group_m_func1_ai_lo_alm
{
	LABEL	[limit_lo];
	ITEMS
	{
		func1_AI_lo_alm_unacknowledged,
		func1_AI_lo_alm_state,
		func1_AI_lo_alm_time_stamp,
		func1_AI_lo_alm_subcode,
		func1_AI_lo_alm_value
	}
}


MENU Group_m_func1_ai_lo_lo_alm
{
	LABEL	[limit_lo_lo];
	ITEMS
	{
		func1_AI_lo_lo_alm_unacknowledged,
		func1_AI_lo_lo_alm_state,
		func1_AI_lo_lo_alm_time_stamp,
		func1_AI_lo_lo_alm_subcode,
		func1_AI_lo_lo_alm_value
	}
}

//Device -> Query Device -> Analog Input index50-
MENU Page_m_query_ai_4
{
	LABEL	[query_ai_4];
	ITEMS
	{
		Group_m_func1_ai_simulate,			/* Index50 */
		func1_AI_out_unit_text	(READ_ONLY),/* Index52 */
		method_set
	}
}

MENU Group_m_func1_ai_simulate
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func1_AI_simulate_status_quality	(READ_ONLY),
		func1_AI_simulate_status_limit		(READ_ONLY),
		func1_AI_simulate_value				(READ_ONLY),
		func1_AI_simulation_enabled			(READ_ONLY)
	}
}

//Device -> Query Device -> Analog Input [Specialist]
MENU OnlineDialog_m_query_ai2
{
	LABEL	FUNC2_TITLE;
	ITEMS
	{
		Page_m_query_ai2_1,
		Page_m_query_ai2_2,
		Page_m_query_ai2_3,
		Page_m_query_ai2_4
	}
}

//Device -> Query Device -> Analog Input index16-22 
MENU Page_m_query_ai2_1
{
	LABEL	[query_ai_1];
	ITEMS
	{
		func2_AI_blk_reserve,				/* Index16 */
		func2_AI_blk_object,
		func2_AI_blk_parent_class,
		func2_AI_blk_class,
		func2_AI_blk_dd_reference,
		func2_AI_blk_dd_rev,
		func2_AI_blk_profile,
		func2_AI_blk_profile_rev,
		func2_AI_blk_execution_time,
		func2_AI_blk_num_parameters,
		func2_AI_blk_index_view_1,
		func2_AI_blk_num_view_lists,
		SEPARATOR,
		func2_AI_st_rev,					/* Index17 */
		func2_AI_tag_desc	(READ_ONLY),	/* Index18 */
		func2_AI_strategy	(READ_ONLY),	/* Index19 */
		func2_AI_alert_key	(READ_ONLY),	/* Index20 */
		func2_AI_target_mode(READ_ONLY),	/* Index21 */
		func2_AI_actual_mode,				/* Index22 */
		func2_AI_permitted_mode,			
		func2_AI_normal_mode,				
		method_set
	}
}

//Device -> Query Device -> Analog Input index23-28 
MENU Page_m_query_ai2_2
{
	LABEL	[query_ai_2];
	ITEMS
	{
		func2_AI_current_state_alarm_sum,	/* Index23 */
		func2_AI_unacknowledged_state_alarm_sum,
		func2_AI_unreported_state_alarm_sum,
		func2_AI_disabled_state_alarm_sum,
		SEPARATOR,
		func2_AI_batch_id,					/* Index24 */
		func2_AI_batch_unit,
		func2_AI_batch_operation,
		func2_AI_batch_phase,
		Group_m_func2_ai_out,				/* Index26 */
		Group_m_func2_ai_pv_scale,			/* Index27 */
		Group_m_func2_ai_out_scale,			/* Index28 */
		method_set
	}
}

MENU Group_m_func2_ai_out
{
	LABEL	[func_out_value];
	ITEMS
	{
		func2_AI_out_value			(READ_ONLY),
		func2_AI_out_status_quality	(READ_ONLY),
		func2_AI_out_status_limit	(READ_ONLY)
	}
}

MENU Group_m_func2_ai_pv_scale
{
	LABEL	[menu_input_measwindow];
	ITEMS
	{
		func2_AI_pv_upper_range_value	(READ_ONLY),
		func2_AI_pv_lower_range_value	(READ_ONLY)
	}
}


MENU Group_m_func2_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func2_AI_out_upper_range_value	(READ_ONLY),
		func2_AI_out_lower_range_value	(READ_ONLY),
		func2_AI_out_unit				(READ_ONLY),
		func2_AI_out_decimal_point		(READ_ONLY)
	}
}

//Device -> Query Device -> Analog Input index29-49 
MENU Page_m_query_ai2_3
{
	LABEL	[query_ai_3];
	ITEMS
	{
		func2_AI_lin_type	(READ_ONLY),	/* Index29 */
		func2_AI_channel	(READ_ONLY),	/* Index30 */
		func2_AI_pv_ftime	(READ_ONLY),	/* Index32 */
		func2_AI_FSafeType	(READ_ONLY),	/* Index33 */
		func2_AI_FSafeValue	(READ_ONLY),	/* Index34 */
		func2_AI_alarm_hys	(READ_ONLY),	/* Index35 */
		func2_AI_hi_hi_lim	(READ_ONLY),	/* Index37 */
		func2_AI_hi_lim		(READ_ONLY),	/* Index39 */
		func2_AI_lo_lim		(READ_ONLY),	/* Index41 */
		func2_AI_lo_lo_lim	(READ_ONLY),	/* Index43 */
		SEPARATOR,
		Group_m_func2_ai_hi_hi_alm,			/* Index46 */
		Group_m_func2_ai_hi_alm,			/* Index47 */
		Group_m_func2_ai_lo_alm,			/* Index48 */
		Group_m_func2_ai_lo_lo_alm,			/* Index49 */
		method_set
	}
}

MENU Group_m_func2_ai_hi_hi_alm
{
	LABEL	[limit_hi_hi];
	ITEMS
	{
		func2_AI_hi_hi_alm_unacknowledged,
		func2_AI_hi_hi_alm_state,
		func2_AI_hi_hi_alm_time_stamp,
		func2_AI_hi_hi_alm_subcode,
		func2_AI_hi_hi_alm_value
	}
}


MENU Group_m_func2_ai_hi_alm
{
	LABEL	[limit_hi];
	ITEMS
	{
		func2_AI_hi_alm_unacknowledged,
		func2_AI_hi_alm_state,
		func2_AI_hi_alm_time_stamp,
		func2_AI_hi_alm_subcode,
		func2_AI_hi_alm_value
	}
}

MENU Group_m_func2_ai_lo_alm
{
	LABEL	[limit_lo];
	ITEMS
	{
		func2_AI_lo_alm_unacknowledged,
		func2_AI_lo_alm_state,
		func2_AI_lo_alm_time_stamp,
		func2_AI_lo_alm_subcode,
		func2_AI_lo_alm_value
	}
}


MENU Group_m_func2_ai_lo_lo_alm
{
	LABEL	[limit_lo_lo];
	ITEMS
	{
		func2_AI_lo_lo_alm_unacknowledged,
		func2_AI_lo_lo_alm_state,
		func2_AI_lo_lo_alm_time_stamp,
		func2_AI_lo_lo_alm_subcode,
		func2_AI_lo_lo_alm_value
	}
}

//Device -> Query Device -> Analog Input index50- 
MENU Page_m_query_ai2_4
{
	LABEL	[query_ai_4];
	ITEMS
	{
		Group_m_func2_ai_simulate,			/* Index50 */
		func2_AI_out_unit_text	(READ_ONLY),/* Index52 */
		method_set
	}
}

MENU Group_m_func2_ai_simulate
{
	LABEL		[func_simulate_value];
	ITEMS
	{
		func2_AI_simulate_status_quality	(READ_ONLY),
		func2_AI_simulate_status_limit		(READ_ONLY),
		func2_AI_simulate_value				(READ_ONLY),
		func2_AI_simulation_enabled			(READ_ONLY)
	}
}


/*
*********************************************************************
   Parameter table
*********************************************************************
*/
MENU Table_Main_Specialist
{
	LABEL	[Table_Main_Specialist_eja_label];
	ITEMS
	{
		Tab_s_easy_setup,
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_interface_set,
		Tab_s_human_interface,
		Tab_s_target_mode
	}
}

MENU Table_Main_Maintenance
{
	LABEL	[Table_Main_Specialist_eja_label];
	ITEMS
	{
		Tab_m_easy_setup,
		Tab_m_ident,
		Tab_m_input,
		Tab_m_output,
		Tab_m_interface_set,
		Tab_m_human_interface,
		Tab_m_target_mode
	}
}

MENU Tab_s_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_s_trans1_eja
	}
}

MENU Tab_m_input
{
	LABEL		[menu_input];
	ITEMS
	{
		Tab_m_trans1_eja
	}
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_s_func1,
        Tab_s_func2
	}
}

MENU Tab_m_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Tab_m_func1,
        Tab_m_func2
	}
}


MENU Tab_s_interface_set
{
	LABEL		[menu_interface_set];
	ITEMS
	{
		trans1_cal_point_lo			(READ_ONLY),
		trans1_cal_point_hi			(READ_ONLY),
		trans1_cal_min_span,
		trans1_trim_mode,
		trans1_trim_pv_zero			(READ_ONLY),
		trans1_ext_zero_enable
	}
}

MENU Tab_m_interface_set
{
	LABEL		[menu_interface_set];
	ITEMS
	{
		trans1_cal_point_lo			(READ_ONLY),
		trans1_cal_point_hi			(READ_ONLY),
		trans1_cal_min_span,
		trans1_trim_mode			(READ_ONLY),
		trans1_trim_pv_zero			(READ_ONLY),
		trans1_ext_zero_enable		(READ_ONLY)	
	}
}



/*-------------------------------------------------------------------
 *     EJA Offline table
 *-----------------------------------------------------------------*/


MENU Tab_s_easy_setup
{
	LABEL		[Tab_easy_setup_label];
	ITEMS
	{
		phys_tag_desc,
		phys_descriptor,
		phys_message,
		phys_install_date,
		Tab_s_easy_setup_trans1,
		Tab_s_easy_setup_func1
	}
}

MENU Tab_m_easy_setup
{
	LABEL		[Tab_easy_setup_label];
	ITEMS
	{
		phys_tag_desc    (READ_ONLY),
		phys_descriptor,
		phys_message,
		phys_install_date  (READ_ONLY),
		Tab_m_easy_setup_trans1,
		Tab_m_easy_setup_func1
	}
}

MENU Tab_s_easy_setup_trans1
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_target_mode,
		trans1_actual_mode,
		Tab_s_trans1_input_meassurerange,
		trans1_lin_type
	}
}

MENU Tab_m_easy_setup_trans1
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_target_mode (READ_ONLY),
		trans1_actual_mode,
		Tab_m_trans1_input_meassurerange,
		trans1_lin_type    (READ_ONLY)
	}
}

MENU Tab_s_easy_setup_func1
{
	LABEL		FUNC1_TITLE;
	ITEMS
	{
		func1_AI_target_mode,
		func1_AI_actual_mode,
		func1_AI_pv_ftime,
		Tab_s_easy_setup_ai_out_scale
	}
}

MENU Tab_m_easy_setup_func1
{
	LABEL		FUNC1_TITLE;
	ITEMS
	{
		func1_AI_target_mode  (READ_ONLY),
		func1_AI_actual_mode
		func1_AI_pv_ftime     (READ_ONLY),
		Tab_m_easy_setup_ai_out_scale
	}
}

MENU Tab_s_easy_setup_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func1_AI_out_lower_range_value,
		func1_AI_out_upper_range_value,
		func1_AI_out_unit,
		func1_AI_out_decimal_point
	}
}

MENU Tab_m_easy_setup_ai_out_scale
{
	LABEL	[menu_output_scalewindow];
	ITEMS
	{
		func1_AI_out_lower_range_value	(READ_ONLY),
		func1_AI_out_upper_range_value	(READ_ONLY),
		func1_AI_out_unit				(READ_ONLY),
		func1_AI_out_decimal_point		(READ_ONLY)
	}
}

MENU Tab_s_trans1_eja
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_st_rev,
		trans1_target_mode,
		trans1_actual_mode,
		trans1_primary_value_type,
		Tab_s_trans1_input_meassurelimit,
		Tab_s_trans1_input_meassurerange,
/*		Tab_s_trans1_input_workrange,*/
		Tab_s_input_table_eja,
		Tab_trans1_eja_pv_unit,
		Tab_s_trans1_temperature,
		Tab_s_trans1_static_pressure
	}
}

MENU Tab_m_trans1_eja
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_st_rev,
		trans1_target_mode			(READ_ONLY),
		trans1_actual_mode,
		trans1_primary_value_type	(READ_ONLY),
		Tab_m_trans1_input_meassurelimit,
		Tab_m_trans1_input_meassurerange,
/*		Tab_m_trans1_input_workrange,*/
		Tab_m_input_table_eja,
		Tab_trans1_eja_pv_unit,
		Tab_m_trans1_temperature,
		Tab_m_trans1_static_pressure
	}
}

MENU Tab_s_input_table_eja
{
	LABEL		[menu_input_table];
	ITEMS
	{
		trans1_lin_type,
		trans1_low_flow_cut_off
	}
}

MENU Tab_m_input_table_eja
{
	LABEL		[menu_input_table];
	ITEMS
	{
		trans1_lin_type				(READ_ONLY),
		trans1_low_flow_cut_off		(READ_ONLY)
	}
}

MENU Tab_trans1_eja_pv_unit
{
	LABEL		[Tab_trans1_eja_pv_unit_label];
	ITEMS
	{
		trans1_primary_value_unit (READ_ONLY)
		
	}
}

MENU Tab_s_trans1_static_pressure
{
	LABEL		[Tab_trans1_static_pressure];
	ITEMS
	{
		trans1_static_press_unit
		
	}
}

MENU Tab_m_trans1_static_pressure
{
	LABEL		[Tab_trans1_static_pressure];
	ITEMS
	{
		trans1_static_press_unit	(READ_ONLY)
		
	}
}

MENU Tab_s_human_interface
{
	LABEL		[Tab_human_interface_label];
	ITEMS
	{
		trans1_display_mode,
        trans1_display_cycle
		
	}
}

MENU Tab_m_human_interface
{
	LABEL		[Tab_human_interface_label];
	ITEMS
	{
		trans1_display_mode		(READ_ONLY),
        trans1_display_cycle	(READ_ONLY)
		
	}
}

MENU Tab_m_func1_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		func1_AI_out_decimal_point (READ_ONLY)
	}
}

MENU Tab_m_func2_interface
{
	LABEL		[menu_interface];
	ITEMS
	{
		func2_AI_out_decimal_point (READ_ONLY)
	}
}

MENU Tab_s_target_mode
{
	LABEL		[target_mode];
	ITEMS
	{
		Tab_s_phys_target_mode,
		Tab_s_trans1_target_mode,
		Tab_s_func1_target_mode,
		Tab_s_func2_target_mode
	}
}

MENU Tab_s_phys_target_mode
{
	LABEL		[physical_block_label];
	ITEMS
	{
		phys_target_mode,
		phys_actual_mode
	}
}

MENU Tab_s_trans1_target_mode
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_target_mode,
		trans1_actual_mode
	}
}

MENU Tab_s_func1_target_mode
{
	LABEL		FUNC1_TITLE;
	ITEMS
	{
		func1_AI_target_mode,
		func1_AI_actual_mode
	}
}

MENU Tab_s_func2_target_mode
{
	LABEL		FUNC2_TITLE;
	ITEMS
	{
		func2_AI_target_mode,
		func2_AI_actual_mode
	}
}

MENU Tab_m_target_mode
{
	LABEL		[target_mode];
	ITEMS
	{
		Tab_m_phys_target_mode,
		Tab_m_trans1_target_mode,
		Tab_m_func1_target_mode,
		Tab_m_func2_target_mode
	}
}

MENU Tab_m_phys_target_mode
{
	LABEL		[physical_block_label];
	ITEMS
	{
		phys_target_mode	(READ_ONLY),
		phys_actual_mode
	}
}

MENU Tab_m_trans1_target_mode
{
	LABEL		TRANS1_TITLE;
	ITEMS
	{
		trans1_target_mode	(READ_ONLY),
		trans1_actual_mode
	}
}

MENU Tab_m_func1_target_mode
{
	LABEL		FUNC1_TITLE;
	ITEMS
	{
		func1_AI_target_mode	(READ_ONLY),
		func1_AI_actual_mode
	}
}

MENU Tab_m_func2_target_mode
{
	LABEL		FUNC2_TITLE;
	ITEMS
	{
		func2_AI_target_mode	(READ_ONLY),
		func2_AI_actual_mode
	}
}


/*
*********************************************************************
   METHOD
*********************************************************************
*/

METHOD method_set
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
	}
}

METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}


/*-------------------------------------------------------------------
 *     Method for zero adjustment
 *-----------------------------------------------------------------*/
METHOD method_trans1_trim_pv_zero
{
    LABEL   "Set Zero";
    CLASS INPUT;
    DEFINITION
    {
		int status;
		int choice_mode;
		
		PUT_MESSAGE("This wizard carries out the zero point adjustment and "
					"automatically sets the applied 0 input value to the output value of 0, "
					"keeping the span constant.");
		
		/* check PB_write_locking */
		EJA_WRITE_LOCKING_MACRO
		
		/* check TB O/S mode */
		EJA_TB_TARGET_MODE_MACRO
		
		/* check TB trim_mode */
		EJA_TRIM_MODE_MACRO
		
		choice_mode= SELECT_FROM_LIST(
					"Be sure whether the lowest pressure was applied to the transmitter.\r\n"
					"\r\nExecute? \r\n", [no_yes]);
		
		if(choice_mode == 0) {
			PUT_MESSAGE("Aborted.\n");
			process_abort();
		}
		
		fassign(trans1_trim_pv_zero,  0.0);
		status = WriteCommand (write_trans1_trim_pv_zero);
		
		if ( status >= ID_FC_ERROR )
		{
			PUT_MESSAGE("Aborted."); 
			process_abort();
		}
//		else
//		{
//			PUT_MESSAGE("Executed!");
//		}
	}
}


/*-------------------------------------------------------------------
 *     Method for Calibration HI / LO
 *-----------------------------------------------------------------*/

VARIABLE dummy_trans1_cal_point_lo
{
	LABEL		[trans_cal_point_lo];		
	HELP		[trans_cal_point_lo_help];
	CLASS		LOCAL;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

VARIABLE dummy_trans1_cal_point_hi
{
	LABEL		[trans_cal_point_hi];
	HELP		[trans_cal_point_hi_help];
	CLASS		LOCAL;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
	}
	HANDLING	READ & WRITE;
}

UNIT EJA_DUMMY_CALIB_SENSOR_UNIT
{
	trans1_sensor_unit:
	
	dummy_trans1_cal_point_hi,
	dummy_trans1_cal_point_lo
}

METHOD method_read_cal_point_lo
{
	LABEL		[trans_cal_point_lo];
	HELP		[trans_cal_point_lo_help];
	DEFINITION
	{
		ReadCommand (read_trans1_cal_point_lo);
		fassign(dummy_trans1_cal_point_lo,  fvar_value(trans1_cal_point_lo));
	}
}

METHOD method_read_cal_point_hi
{
	LABEL		[trans_cal_point_hi];
	HELP		[trans_cal_point_hi_help];
	DEFINITION
	{
		ReadCommand (read_trans1_cal_point_hi);
		fassign(dummy_trans1_cal_point_hi,  fvar_value(trans1_cal_point_hi));
	}
}

METHOD method_execute_cal_point_lo
{
    LABEL [execute]; 
    CLASS INPUT;
    DEFINITION
    {
		int   status;
		int   choice_mode;
		long  var_id[3];
		
		EJA_SENSOR_CALIBRATION_MACRO
		
		/* check PB_write_locking */
		EJA_WRITE_LOCKING_MACRO
		
		/* check TB O/S mode */
		EJA_TB_TARGET_MODE_MACRO
		
		/* check TB trim_mode */
		EJA_TRIM_MODE_MACRO
		
		ReadCommand (read_trans1_trimmed_value);
		ReadCommand (read_trans1_sensor_unit);
		
		var_id[0] = VARID (trans1_trimmed_value);
		var_id[1] = VARID (trans1_sensor_unit);
		var_id[2] = VARID (dummy_trans1_cal_point_lo);
		
		choice_mode = select_from_list(
						"Be sure that the lower pressure is applied to the transmitter.\r\n"
						"\r\nThe current Pressure Trimmed Value = %{0} %{1} \r\n"
						"\r\n\nThe new Lower Calibration Point = %{2} %{1} \r\n"
						"\r\n\nExecute? \r\n", var_id, [no_yes]);
		
		switch (choice_mode){
			case 0:
				PUT_MESSAGE("Aborted.\n");
				process_abort();
				break;
			
			case 1:
				fassign(trans1_cal_point_lo,  fvar_value(dummy_trans1_cal_point_lo));
				status = WriteCommand (write_trans1_cal_point_lo);
				
				ReadCommand (read_trans1_cal_point_lo); /* update dummy_trans1_cal_point_lo */
				fassign(dummy_trans1_cal_point_lo,  fvar_value(trans1_cal_point_lo));
				
				if ( status >= ID_FC_ERROR ){
					PUT_MESSAGE("Aborted."); 
					process_abort();
				}
//				else
//				{
//					PUT_MESSAGE("Executed!");
//				}
				break;
		}
	}
}


METHOD method_execute_cal_point_hi
{
    LABEL [execute]; 
    CLASS INPUT;
    DEFINITION
    {
		int   status;
		int   choice_mode;
		long  var_id[3];
		
		EJA_SENSOR_CALIBRATION_MACRO
		
		/* check PB_write_locking */
		EJA_WRITE_LOCKING_MACRO
		
		/* check TB O/S mode */
		EJA_TB_TARGET_MODE_MACRO
		
		/* check TB trim_mode */
		EJA_TRIM_MODE_MACRO
		
		ReadCommand (read_trans1_trimmed_value);
		ReadCommand (read_trans1_sensor_unit);
		
		var_id[0] = VARID (trans1_trimmed_value);
		var_id[1] = VARID (trans1_sensor_unit);
		var_id[2] = VARID (dummy_trans1_cal_point_hi);
		
		choice_mode = select_from_list(
						"Be sure that the upper pressure is applied to the transmitter.\r\n"
						"\r\nThe current Pressure Trimmed Value = %{0} %{1} \r\n"
						"\r\n\nThe new Upper Calibration Point = %{2} %{1} \r\n"
						"\r\n\nExecute? \r\n", var_id, [no_yes]);
		
		switch (choice_mode){
			case 0:
				PUT_MESSAGE("Aborted.\n");
				process_abort();
				break;
			
			case 1:
				fassign(trans1_cal_point_hi,  fvar_value(dummy_trans1_cal_point_hi));
				status = WriteCommand (write_trans1_cal_point_hi);
				
				ReadCommand (read_trans1_cal_point_hi); /* update dummy_trans1_cal_point_hi */
				fassign(dummy_trans1_cal_point_hi,  fvar_value(trans1_cal_point_hi));
				
				if ( status >= ID_FC_ERROR ){
					PUT_MESSAGE("Aborted"); 
					process_abort();
				}
//				else
//				{
//					PUT_MESSAGE("Executed!");
//				}
				break;
		}
	}
}


/*-------------------------------------------------------------------
 *     Method for Download / Upload
 *-----------------------------------------------------------------*/
VARIABLE local_abort
{
	LABEL   "local_abort";
	CLASS   LOCAL;
	TYPE    INTEGER
	{
		DEFAULT_VALUE   0;
	}
}

METHOD abort_load_to_device
{
	LABEL "aborting_return_to_normal";
	DEFINITION
	{
		local_abort=1;
		PUT_MESSAGE([Procedure_aborted]);
	}
}

METHOD  method_pre_writelocking
{
	LABEL   [method_pre_upload_target_mode_os_label];
	DEFINITION
	{
		add_abort_method(abort_load_to_device);
		local_abort = 0;
		
		/* check PB_write_locking */
		EJA_WRITE_LOCKING_MACRO
	}
}


METHOD  method_pre_upload_target_mode_os
{
	LABEL   [method_pre_upload_target_mode_os_label];
	DEFINITION
	{
		int status;
		
		iassign( trans1_target_mode, 0x80) ;
		iassign( phys_target_mode, 0x80) ;
		iassign( func1_AI_target_mode, 0x80) ;
		iassign( func2_AI_target_mode, 0x80) ;
		
		status = WriteCommand (write_phys_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_trans1_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_func1_AI_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_func2_AI_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		
	}
}


METHOD  method_post_upload_target_mode_auto
{
	LABEL   [method_post_upload_target_mode_auto_label];
	DEFINITION
	{
		int status;
		
		iassign( trans1_target_mode, 0x08) ;
		iassign( phys_target_mode, 0x08) ;
		iassign( func1_AI_target_mode, 0x08) ;
		iassign( func2_AI_target_mode, 0x08) ;
		
		status = WriteCommand (write_phys_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_trans1_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_func1_AI_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		status = WriteCommand (write_func2_AI_target_mode);
		if ( status >= ID_FC_ERROR )
		{
			ACKNOWLEDGE([acknowledge_process_aborted]);
			process_abort();
		}
		
	}
}


/*
*********************************************************************
   Upload /Download
*********************************************************************
*/
MENU upload_variables
{
	LABEL		[menu_load_to_device];
	
	PRE_WRITE_ACTIONS
	{
		method_pre_writelocking,
		method_pre_upload_target_mode_os
	}
	POST_WRITE_ACTIONS
	{
		method_post_upload_target_mode_auto
	}
	ITEMS
	{
		IF (ivar_value(local_abort) == 0)
		{
		/* PB */
		phys_tag_desc,					
		phys_descriptor,				
		phys_message,					
		phys_install_date,				
		phys_ident_number,				
		
		/* TB */
		trans1_lin_type,				
		trans1_sensor_unit,				
		trans1_temperature_unit,		
		trans1_secondary_value_1_unit,	
		trans1_static_press_unit,		
		trans1_primary_value_type,		
		trans1_scale_in_lower_value,	
		trans1_scale_in_upper_value,	
		trans1_low_flow_cut_off,		
		trans1_trim_mode,				
		trans1_ext_zero_enable,			
		trans1_display_mode,			
		trans1_display_cycle,			
		
		/* AI1 */
		func1_AI_out_upper_range_value,	
		func1_AI_out_lower_range_value,	
		func1_AI_out_unit,				
		func1_AI_out_decimal_point,		
		func1_AI_batch_id,				
		func1_AI_batch_unit,			
		func1_AI_batch_operation,		
		func1_AI_batch_phase			
		func1_AI_channel,				
		func1_AI_pv_ftime,				
		func1_AI_FSafeType,				
		func1_AI_FSafeValue,			
		func1_AI_alarm_hys,				
		func1_AI_hi_hi_lim,				
		func1_AI_hi_lim,				
		func1_AI_lo_lim,				
		func1_AI_lo_lo_lim,				
		func1_AI_out_unit_text,			

		/* AI2 */
		func2_AI_pv_upper_range_value,
		func2_AI_pv_lower_range_value,
		func2_AI_out_upper_range_value,	
		func2_AI_out_lower_range_value,	
		func2_AI_out_unit,				
		func2_AI_out_decimal_point,		
		func2_AI_batch_id,				
		func2_AI_batch_unit,			
		func2_AI_batch_operation,		
		func2_AI_batch_phase			
		func2_AI_channel,				
		func2_AI_pv_ftime,				
		func2_AI_FSafeType,				
		func2_AI_FSafeValue,			
		func2_AI_alarm_hys,				
		func2_AI_hi_hi_lim,				
		func2_AI_hi_lim,				
		func2_AI_lo_lim,				
		func2_AI_lo_lo_lim,				
		func2_AI_out_unit_text			
		
		}
	}
}


MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{
		phys_tag_desc,
		phys_descriptor,
		phys_message,
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_blk_profile_rev,
		phys_st_rev,
		phys_ident_number,
		phys_install_date,
		phys_soft_desc,
		trans1_serial_number,
		
		trans1_st_rev,
		trans1_target_mode,
		trans1_actual_mode,
		trans1_primary_value_type,
		trans1_sensor_unit,
		trans1_sensor_low_limit,
		trans1_sensor_high_limit,
		trans1_secondary_value_1_unit,
		trans1_scale_in_lower_value,
		trans1_scale_in_upper_value,
		trans1_lin_type,
		trans1_low_flow_cut_off,
		trans1_primary_value_unit,
		trans1_temperature_unit,
		trans1_static_press_unit,
	
		func1_AI_st_rev,
		func1_AI_target_mode,
		func1_AI_actual_mode,
		func1_AI_channel,
		func1_AI_out_unit,
		func1_AI_out_unit_text,
		func1_AI_pv_ftime,
		func1_AI_batch_id,
		func1_AI_batch_unit,
		func1_AI_batch_operation,
		func1_AI_batch_phase,
		func1_AI_out_lower_range_value,
		func1_AI_out_upper_range_value,
		func1_AI_hi_hi_lim,
		func1_AI_hi_lim,
		func1_AI_lo_lim,
		func1_AI_lo_lo_lim,
		func1_AI_alarm_hys,
		func1_AI_FSafeType,
		func1_AI_FSafeValue,
		func1_AI_out_decimal_point,
		
		func2_AI_st_rev,
		func2_AI_target_mode,
		func2_AI_actual_mode,
		func2_AI_channel,
		func2_AI_out_unit,
		func2_AI_out_unit_text,
		func2_AI_pv_ftime,
		func2_AI_batch_id,
		func2_AI_batch_unit,
		func2_AI_batch_operation,
		func2_AI_batch_phase,
		func2_AI_pv_lower_range_value,
		func2_AI_pv_upper_range_value,
		func2_AI_out_lower_range_value,
		func2_AI_out_upper_range_value,
		func2_AI_hi_hi_lim,
		func2_AI_hi_lim,
		func2_AI_lo_lim,
		func2_AI_lo_lo_lim,
		func2_AI_alarm_hys,
		func2_AI_FSafeType,
		func2_AI_FSafeValue,
		func2_AI_out_decimal_point,
		
		trans1_cal_point_lo,
		trans1_cal_point_hi,
		trans1_cal_min_span,
		trans1_trim_mode,
		trans1_trim_pv_zero,
		trans1_ext_zero_enable,
		trans1_display_mode,
		trans1_display_cycle,
		
		phys_target_mode,
		phys_actual_mode
	}
}

