/***************************************************************************************************
*  Copyright (C) Yokogawa Electric Corporation 2003,2004  All Rights Reserved.                     *
*
*  $Workfile:   YEC_EJA0101PAmacro.inc  $
*    $Author:   eja_leader  $
*  $Revision:   1.0  $
*      $Date:   11 Apr 2007 13:39:08  $
*                                                                                                  *
****************************************************************************************************
*
*  PROJECT_NAME        EJA Profibus PA
*
*  FIRST_AUTHOR        Madoka Ueno
*  
*  FILE_DESCRIPTION    EJA PA PDM macro definitions
*  
*  FUNCTIONAL_MODULE_DESCRIPTION  Include file
*  
*  DICTIONARY          YEC_EJA0101PA.dct & SIEMENS standard dictionary
* 
*  RELATED_DOCUMENTS
*    Document No.        Name               Title
*---------------------------------------------------------------------------------------------------
*    STR-PBEJA-B007      M. Ueno            EJA PROFIBUS PA EDD Specification
*=================================================================================================*/

/*
*********************************************************************
   for IMPORT & ddl
*********************************************************************
*/

#define  DEFAULT_VALUE_phys_blk_profile		0x4002

/* PB */
#define DEFAULT_MANUFACTURER_ID					55
#define DEVICE_TYPE								"EJA"
#define DEFAULT_phys_ident_number				1
#define DEFAULT_VALUE_phys_device_certification	""

/* AI1 */
#define FUNC1_TITLE								[func1_AI]
#define DEFAULT_VALUE_func1_upper_range_value	100.0
#define DEFAULT_VALUE_func1_AI_pv_ftime			2.0
#define FUNC1_DEFAULT_UNIT						1342   /* EJA AI1 default unit=1342= */
#define	FUNC1_CHANNEL_PRIMARY					0x0112 /* 0x01 TrdId; 0x12 => 18 => PV */
#define FUNC1_CHANNEL_PRIMARY_TEXT				"primary"
#define FUNC1_CHANNEL_LIST						{ 0x112,	"Primary Value"}

/* AI2 */
#define FUNC2_TITLE								[func2_AI]
#define DEFAULT_VALUE_func2_upper_range_value	100.0
#define DEFAULT_VALUE_func2_AI_pv_ftime			2.0
#define FUNC2_DEFAULT_UNIT						1342	/* EJA AI2 default unit=1342= */
#define	FUNC2_CHANNEL_PRIMARY					0x013B	/* 0x01 TrdId; 0x3B => 59 => StaticPressure */
#define FUNC2_CHANNEL_PRIMARY_TEXT				"static pressure"
#define FUNC2_CHANNEL_LIST						{ 0x13b,	"Static Pressure Value"}

/* TB */
#define TRANS1_TITLE							"Transducer Block" 

// ! The following definitions must not be applied to DTM.
#define NO_trans1_sens_fill_fluid
#define NO_trans1_sensor_max_static_pres
#define NO_trans1_diaphragm_mat
#define NO_trans1_sensor_o_ring_mat
#define NO_trans1_proc_conn_type
#define NO_trans1_proc_conn_mat
#define NO_trans1_secondary_value_2
#define NO_trans1_secondary_value_2_unit
#define NO_trans1_min_sensor_value
#define NO_trans1_max_sensor_value
#define NO_trans1_min_temperature
#define NO_trans1_max_temperature




/* TB SESOR_UNIT, SECONDARY_VALUE_1_UNIT, STATIC_PRESSURE_UNIT */
#define	DEF_TRANS_SENSOR_UNIT													\
		DEFAULT_VALUE	1133 ;													\
		{ 1130, [unit_1130],		[unit_1130_help]	},	/* Pa           */	\
		{ 1131, [unit_1131],		[unit_1131_help]	},	/* GPa          */	\
		{ 1132, [unit_1132],		[unit_1132_help]	},	/* MPa          */	\
		{ 1133, [unit_1133],		[unit_1133_help]	},	/* kPa          */	\
		{ 1134, [unit_1134],		[unit_1134_help]	},	/* mPa          */	\
		{ 1135, [unit_1135],		[unit_1135_help]	},	/* Pa         */	\
		{ 1136, [unit_1136],		[unit_1136_help]	},	/* hPa          */	\
		{ 1137, [unit_1137],		[unit_1137_help]	},	/* bar          */	\
		{ 1138, [unit_1138],		[unit_1138_help]	},	/* mbar         */	\
		{ 1139, [unit_1139],		[unit_1139_help]	},	/* torr         */	\
		{ 1140, [unit_1140],		[unit_1140_help]	},	/* atm          */	\
		{ 1141, [unit_1141],		[unit_1141_help]	},	/* psi          */	\
		{ 1142, [unit_1142],		[unit_1142_help]	},	/* psia         */	\
		{ 1143, [unit_1143],		[unit_1143_help]	},	/* psig         */	\
		{ 1144, [unit_1144],		[unit_1144_help]	},	/* g/cm2        */	\
		{ 1145, [unit_1145],		[unit_1145_help]	},	/* kg/cm2       */	\
		{ 1146, [unit_1146],		[unit_1146_help]	},	/* inH20        */	\
		{ 1147, [unit_1147],		[unit_1147_help]	},	/* inH20(4degC) */	\
		{ 1148, [unit_1148],		[unit_1148_help]	},	/* inH20(68degF)*/	\
		{ 1149, [unit_1149],		[unit_1149_help]	},	/* mmH2O        */	\
		{ 1150, [unit_1150],		[unit_1150_help]	},	/* mmH2O(4degC) */	\
		{ 1151, [unit_1151],		[unit_1151_help]	},	/* mmH2O(68degF)*/	\
		{ 1152, [unit_1152],		[unit_1152_help]	},	/* ftH2O        */	\
		{ 1153, [unit_1153],		[unit_1153_help]	},	/* ftH2O(4degC) */	\
		{ 1154, [unit_1154],		[unit_1154_help]	},	/* ftH2O(68degF)*/	\
		{ 1155, [unit_1155],		[unit_1155_help]	},	/* inHg         */	\
		{ 1156, [unit_1156],		[unit_1156_help]	},	/* inHg(0degC)  */	\
		{ 1157, [unit_1157],		[unit_1157_help]	},	/* mmHg         */	\
		{ 1158, [unit_1158],		[unit_1158_help]	}	/* mmHg(0degC)  */

#define	DEF_TRANS_BLK_CLASS								\
		DEFAULT_VALUE		4;							\
		{	1,		[trans_pres_blk_class_DIFF]	},		\
		{	2,		[trans_pres_blk_class_ABS]	},		\
		{	3,		[trans_pres_blk_class_GAGE]	},		\
		{	4,		[trans_pres_blk_class_PLF]	},		\
		{	250,	[not_used] 					},		\
		{	251,	[none]						},		\
		{	252,	[unknown]					},		\
		{	253,	[special]					}

#define	DEF_TRANS_SENSOR_TYPE											\
		{	0,		"Diff (DP) PN 160"									\
					"|de|Diff-Druck PN 160"								\
					"|fr|Pression Diff PN 160"							\
					"|sp|Presin dif. PN 160"							\
					"|it|Pressione differenziale PN 160" },				\
		{	1,		[gage]							},					\
		{	2,		[absolute]						},					\
		{	3,		"Diff (HP) PN 420"									\
					"|de|Diff-Druck PN 420"								\
					"|fr|Pression Diff PN 420"							\
					"|sp|Presin dif. PN 420"							\
					"|it|Pressione differenziale PN 420" },				\
		{	4,		[liquid_level]					},					\
		{	5,		"Draft range (DR) PN 32"							\
					"|de|Kleiner Diff-Druck PN 32"						\
					"|fr|Faible pression Diff PN 32"					\
					"|sp|Presin dif. pequea PN 32"					\
					"|it|Piccola pressione differenziale PN 32" },		\
		{	126,	[resonant]					},						\
		{	239,	"Diff (DP) PN 315"									\
					"|de|Diff-Druck PN 315"								\
					"|fr|Pression Diff PN 315"							\
					"|sp|Presin dif. Pn 315"							\
					"|it|Pressione differenziale PN 315" },				\
		{	253,	[special]						}

#define DEF_TRANS_PRIMARY_VALUE_UNIT									\
		DEFAULT_VALUE	1342 ;											\
		UNIT_LIST
#define DEF_TRANS_SECONDARY_VALUE_1_UNIT		DEF_TRANS_SENSOR_UNIT


/* DIAGNOSIS EXTENSION */
#define DIA_EXT_01000000			0x01000000
#define DIA_EXT_02000000			0x02000000
#define DIA_EXT_04000000			0x04000000
#define DIA_EXT_08000000			0x08000000
#define DIA_EXT_10000000			0x10000000
#define DIA_EXT_20000000			0x20000000
#define DIA_EXT_40000000			0x40000000
#define DIA_EXT_80000000			0x80000000

#define DIA_EXT_00010000			0x00010000
#define DIA_EXT_00020000			0x00020000
#define DIA_EXT_00040000			0x00040000
#define DIA_EXT_00080000			0x00080000
#define DIA_EXT_00100000			0x00100000
#define DIA_EXT_00200000			0x00200000
#define DIA_EXT_00400000			0x00400000
#define DIA_EXT_00800000			0x00800000

#define DIA_EXT_00000100			0x00000100
#define DIA_EXT_00000200			0x00000200
#define DIA_EXT_00000400			0x00000400
#define DIA_EXT_00000800			0x00000800
#define DIA_EXT_00001000			0x00001000
#define DIA_EXT_00002000			0x00002000
#define DIA_EXT_00004000			0x00004000
#define DIA_EXT_00008000			0x00008000

#define DIA_EXT_00000001			0x00000001
#define DIA_EXT_00000002			0x00000002
#define DIA_EXT_00000004			0x00000004
#define DIA_EXT_00000008			0x00000008
#define DIA_EXT_00000010			0x00000010
#define DIA_EXT_00000020			0x00000020
#define DIA_EXT_00000040			0x00000040
#define DIA_EXT_00000080			0x00000080

#define	ID_FC_ERROR				3000

